@@ -12,10 +12,11 @@ from vdb.lib.gha import GitHubSource
 from vdb.lib.nvd import NvdSource
 from vdb.lib.osv import OSVSource
 
-# Temp directories were not working on macOS GitHub runners
 test_tmp_dir = os.getenv("TEST_VDB_HOME", tempfile.mkdtemp(prefix="vdb6-tests-"))
 os.makedirs(test_tmp_dir, exist_ok=True)
-db6.get(os.path.join(test_tmp_dir, "data.vdb6"), os.path.join(test_tmp_dir, "index.vdb6"))
+
+# Use in-memory database for testing
+db6.get(":memory:", ":memory:")
 
 
 @pytest.fixture
@@ -23,7 +24,7 @@ def test_cve_json():
     test_cve_data = os.path.join(
         os.path.dirname(os.path.realpath(__file__)), "data", "cve_data.json"
     )
-    with open(test_cve_data, "r") as fp:
+    with open(test_cve_data, mode="r", encoding="utf-8") as fp:
         return json.loads(fp.read())
 
 
@@ -32,7 +33,7 @@ def test_cve_wconfig_json():
     test_cve_data = os.path.join(
         os.path.dirname(os.path.realpath(__file__)), "data", "cve_wconfig_data.json"
     )
-    with open(test_cve_data, "r") as fp:
+    with open(test_cve_data, mode="r", encoding="utf-8") as fp:
         return json.loads(fp.read())
 
 
@@ -41,7 +42,7 @@ def test_nvd_api_json1():
     test_cve_data = os.path.join(
         os.path.dirname(os.path.realpath(__file__)), "data", "CVE-2024-0057.json"
     )
-    with open(test_cve_data, "r") as fp:
+    with open(test_cve_data, mode="r", encoding="utf-8") as fp:
         return json.loads(fp.read())
 
 
@@ -50,7 +51,7 @@ def test_nvd_api_json2():
     test_cve_data = os.path.join(
         os.path.dirname(os.path.realpath(__file__)), "data", "CVE-2024-21312.json"
     )
-    with open(test_cve_data, "r") as fp:
+    with open(test_cve_data, mode="r", encoding="utf-8") as fp:
         return json.loads(fp.read())
 
 
@@ -59,7 +60,7 @@ def test_nvd_api_json3():
     test_cve_data = os.path.join(
         os.path.dirname(os.path.realpath(__file__)), "data", "CVE-2024-23771.json"
     )
-    with open(test_cve_data, "r") as fp:
+    with open(test_cve_data, mode="r", encoding="utf-8") as fp:
         return json.loads(fp.read())
 
 
@@ -68,7 +69,7 @@ def test_nvd_api_json4():
     test_cve_data = os.path.join(
         os.path.dirname(os.path.realpath(__file__)), "data", "CVE-2015-3192.json"
     )
-    with open(test_cve_data, "r") as fp:
+    with open(test_cve_data, mode="r", encoding="utf-8") as fp:
         return json.loads(fp.read())
 
 
@@ -77,7 +78,34 @@ def test_nvd_api_git_json():
     test_cve_data = os.path.join(
         os.path.dirname(os.path.realpath(__file__)), "data", "CVE-2023-52426.json"
     )
-    with open(test_cve_data, "r") as fp:
+    with open(test_cve_data, mode="r", encoding="utf-8") as fp:
+        return json.loads(fp.read())
+
+
+@pytest.fixture
+def test_nvd_api_cpes_json():
+    test_cve_data = os.path.join(
+        os.path.dirname(os.path.realpath(__file__)), "data", "CVE-2021-27434.json"
+    )
+    with open(test_cve_data, mode="r", encoding="utf-8") as fp:
+        return json.loads(fp.read())
+
+
+@pytest.fixture
+def test_nvd_api_signal_json():
+    test_cve_data = os.path.join(
+        os.path.dirname(os.path.realpath(__file__)), "data", "CVE-2018-9840.json"
+    )
+    with open(test_cve_data, mode="r", encoding="utf-8") as fp:
+        return json.loads(fp.read())
+
+
+@pytest.fixture
+def test_nvd_api_at_json():
+    test_cve_data = os.path.join(
+        os.path.dirname(os.path.realpath(__file__)), "data", "CVE-2024-3801.json"
+    )
+    with open(test_cve_data, mode="r", encoding="utf-8") as fp:
         return json.loads(fp.read())
 
 
@@ -86,7 +114,25 @@ def test_osv_rust_json():
     test_cve_data = os.path.join(
         os.path.dirname(os.path.realpath(__file__)), "data", "osv_rust_data.json"
     )
-    with open(test_cve_data, "r") as fp:
+    with open(test_cve_data, mode="r", encoding="utf-8") as fp:
+        return json.loads(fp.read())
+
+
+@pytest.fixture
+def test_osv_rust2_json():
+    test_cve_data = os.path.join(
+        os.path.dirname(os.path.realpath(__file__)), "data", "RUSTSEC-2024-0343.json"
+    )
+    with open(test_cve_data, mode="r", encoding="utf-8") as fp:
+        return json.loads(fp.read())
+
+
+@pytest.fixture
+def test_osv_rust3_json():
+    test_cve_data = os.path.join(
+        os.path.dirname(os.path.realpath(__file__)), "data", "GHSA-vc2p-r46x-m3vx.json"
+    )
+    with open(test_cve_data, mode="r", encoding="utf-8") as fp:
         return json.loads(fp.read())
 
 
@@ -95,7 +141,7 @@ def test_osv_mvn_json():
     test_cve_data = os.path.join(
         os.path.dirname(os.path.realpath(__file__)), "data", "osv_mvn_data.json"
     )
-    with open(test_cve_data, "r") as fp:
+    with open(test_cve_data, mode="r", encoding="utf-8") as fp:
         return json.loads(fp.read())
 
 
@@ -104,7 +150,7 @@ def test_osv_mixed_json():
     test_cve_data = os.path.join(
         os.path.dirname(os.path.realpath(__file__)), "data", "osv_mixed_data.json"
     )
-    with open(test_cve_data, "r") as fp:
+    with open(test_cve_data, mode="r", encoding="utf-8") as fp:
         return json.loads(fp.read())
 
 
@@ -113,7 +159,25 @@ def test_osv_go_json():
     test_cve_data = os.path.join(
         os.path.dirname(os.path.realpath(__file__)), "data", "GO-2022-0646.json"
     )
-    with open(test_cve_data, "r") as fp:
+    with open(test_cve_data, mode="r", encoding="utf-8") as fp:
+        return json.loads(fp.read())
+
+
+@pytest.fixture
+def test_osv_go2_json():
+    test_cve_data = os.path.join(
+        os.path.dirname(os.path.realpath(__file__)), "data", "GO-2022-0251.json"
+    )
+    with open(test_cve_data, mode="r", encoding="utf-8") as fp:
+        return json.loads(fp.read())
+
+
+@pytest.fixture
+def test_osv_go3_json():
+    test_cve_data = os.path.join(
+        os.path.dirname(os.path.realpath(__file__)), "data", "GHSA-xrjj-mj9h-534m.json"
+    )
+    with open(test_cve_data, mode="r", encoding="utf-8") as fp:
         return json.loads(fp.read())
 
 
@@ -122,7 +186,7 @@ def test_osv_pypi_json():
     test_cve_data = os.path.join(
         os.path.dirname(os.path.realpath(__file__)), "data", "osv-pypi.json"
     )
-    with open(test_cve_data, "r") as fp:
+    with open(test_cve_data, mode="r", encoding="utf-8") as fp:
         return json.loads(fp.read())
 
 
@@ -131,7 +195,7 @@ def test_osv_pypi2_json():
     test_cve_data = os.path.join(
         os.path.dirname(os.path.realpath(__file__)), "data", "osv-pypi2.json"
     )
-    with open(test_cve_data, "r") as fp:
+    with open(test_cve_data, mode="r", encoding="utf-8") as fp:
         return json.loads(fp.read())
 
 
@@ -140,7 +204,7 @@ def test_osv_pypi3_json():
     test_cve_data = os.path.join(
         os.path.dirname(os.path.realpath(__file__)), "data", "osv-pypi-ujson-bug.json"
     )
-    with open(test_cve_data, "r") as fp:
+    with open(test_cve_data, mode="r", encoding="utf-8") as fp:
         return json.loads(fp.read())
 
 
@@ -149,7 +213,7 @@ def test_osv_swift_json():
     test_cve_data = os.path.join(
         os.path.dirname(os.path.realpath(__file__)), "data", "osv_swift_data.json"
     )
-    with open(test_cve_data, "r") as fp:
+    with open(test_cve_data, mode="r", encoding="utf-8") as fp:
         return json.loads(fp.read())
 
 
@@ -158,7 +222,7 @@ def test_osv_swift2_json():
     test_cve_data = os.path.join(
         os.path.dirname(os.path.realpath(__file__)), "data", "osv_swift_data2.json"
     )
-    with open(test_cve_data, "r") as fp:
+    with open(test_cve_data, mode="r", encoding="utf-8") as fp:
         return json.loads(fp.read())
 
 
@@ -167,7 +231,7 @@ def test_osv_mevents_json():
     test_cve_data = os.path.join(
         os.path.dirname(os.path.realpath(__file__)), "data", "osv_multi_events.json"
     )
-    with open(test_cve_data, "r") as fp:
+    with open(test_cve_data, mode="r", encoding="utf-8") as fp:
         return json.loads(fp.read())
 
 
@@ -176,7 +240,7 @@ def test_osv_git_json():
     test_cve_data = os.path.join(
         os.path.dirname(os.path.realpath(__file__)), "data", "osv-git.json"
     )
-    with open(test_cve_data, "r") as fp:
+    with open(test_cve_data, mode="r", encoding="utf-8") as fp:
         return json.loads(fp.read())
 
 
@@ -185,7 +249,16 @@ def test_osv_npm_star_json():
     test_cve_data = os.path.join(
         os.path.dirname(os.path.realpath(__file__)), "data", "osv-npm-star-bug.json"
     )
-    with open(test_cve_data, "r") as fp:
+    with open(test_cve_data, mode="r", encoding="utf-8") as fp:
+        return json.loads(fp.read())
+
+
+@pytest.fixture
+def test_osv_maven_cvss4_json():
+    test_cve_data = os.path.join(
+        os.path.dirname(os.path.realpath(__file__)), "data", "osv-maven-cvss4.json"
+    )
+    with open(test_cve_data, mode="r", encoding="utf-8") as fp:
         return json.loads(fp.read())
 
 
@@ -194,7 +267,25 @@ def test_osv_mal_json():
     test_cve_data = os.path.join(
         os.path.dirname(os.path.realpath(__file__)), "data", "MAL-2024-1396.json"
     )
-    with open(test_cve_data, "r") as fp:
+    with open(test_cve_data, mode="r", encoding="utf-8") as fp:
+        return json.loads(fp.read())
+
+
+@pytest.fixture
+def test_osv_mal2_json():
+    test_cve_data = os.path.join(
+        os.path.dirname(os.path.realpath(__file__)), "data", "MAL-2024-1333.json"
+    )
+    with open(test_cve_data, mode="r", encoding="utf-8") as fp:
+        return json.loads(fp.read())
+
+
+@pytest.fixture
+def test_osv_mvn_single_json():
+    test_cve_data = os.path.join(
+        os.path.dirname(os.path.realpath(__file__)), "data", "osv-maven-single.json"
+    )
+    with open(test_cve_data, mode="r", encoding="utf-8") as fp:
         return json.loads(fp.read())
 
 
@@ -203,7 +294,7 @@ def test_aqua_alsa_json():
     test_cve_data = os.path.join(
         os.path.dirname(os.path.realpath(__file__)), "data", "ALSA-2022-8580.json"
     )
-    with open(test_cve_data, "r") as fp:
+    with open(test_cve_data, mode="r", encoding="utf-8") as fp:
         return json.loads(fp.read())
 
 
@@ -212,7 +303,7 @@ def test_aqua_alas_json():
     test_cve_data = os.path.join(
         os.path.dirname(os.path.realpath(__file__)), "data", "ALAS2022-2022-207.json"
     )
-    with open(test_cve_data, "r") as fp:
+    with open(test_cve_data, mode="r", encoding="utf-8") as fp:
         return json.loads(fp.read())
 
 
@@ -221,7 +312,7 @@ def test_aqua_rlsa_json():
     test_cve_data = os.path.join(
         os.path.dirname(os.path.realpath(__file__)), "data", "RLSA-2022-7730.json"
     )
-    with open(test_cve_data, "r") as fp:
+    with open(test_cve_data, mode="r", encoding="utf-8") as fp:
         return json.loads(fp.read())
 
 
@@ -230,7 +321,7 @@ def test_aqua_ubuntu_json():
     test_cve_data = os.path.join(
         os.path.dirname(os.path.realpath(__file__)), "data", "CVE-2022-45406.json"
     )
-    with open(test_cve_data, "r") as fp:
+    with open(test_cve_data, mode="r", encoding="utf-8") as fp:
         return json.loads(fp.read())
 
 
@@ -239,7 +330,7 @@ def test_aqua_ubuntu2_json():
     test_cve_data = os.path.join(
         os.path.dirname(os.path.realpath(__file__)), "data", "CVE-2022-3715.json"
     )
-    with open(test_cve_data, "r") as fp:
+    with open(test_cve_data, mode="r", encoding="utf-8") as fp:
         return json.loads(fp.read())
 
 
@@ -248,7 +339,7 @@ def test_aqua_ubuntu1_json():
     test_cve_data = os.path.join(
         os.path.dirname(os.path.realpath(__file__)), "data", "CVE-2022-6083.json"
     )
-    with open(test_cve_data, "r") as fp:
+    with open(test_cve_data, mode="r", encoding="utf-8") as fp:
         return json.loads(fp.read())
 
 
@@ -257,7 +348,7 @@ def test_aqua_ubuntu3_json():
     test_cve_data = os.path.join(
         os.path.dirname(os.path.realpath(__file__)), "data", "CVE-2022-3219.json"
     )
-    with open(test_cve_data, "r") as fp:
+    with open(test_cve_data, mode="r", encoding="utf-8") as fp:
         return json.loads(fp.read())
 
 
@@ -266,7 +357,7 @@ def test_aqua_ubuntu4_json():
     test_cve_data = os.path.join(
         os.path.dirname(os.path.realpath(__file__)), "data", "CVE-2022-32081.json"
     )
-    with open(test_cve_data, "r") as fp:
+    with open(test_cve_data, mode="r", encoding="utf-8") as fp:
         return json.loads(fp.read())
 
 
@@ -275,7 +366,7 @@ def test_aqua_ubuntu5_json():
     test_cve_data = os.path.join(
         os.path.dirname(os.path.realpath(__file__)), "data", "CVE-2022-3821.json"
     )
-    with open(test_cve_data, "r") as fp:
+    with open(test_cve_data, mode="r", encoding="utf-8") as fp:
         return json.loads(fp.read())
 
 
@@ -284,7 +375,7 @@ def test_aqua_redhat_json():
     test_cve_data = os.path.join(
         os.path.dirname(os.path.realpath(__file__)), "data", "CVE-2022-45418.json"
     )
-    with open(test_cve_data, "r") as fp:
+    with open(test_cve_data, mode="r", encoding="utf-8") as fp:
         return json.loads(fp.read())
 
 
@@ -293,7 +384,16 @@ def test_aqua_redhat2_json():
     test_cve_data = os.path.join(
         os.path.dirname(os.path.realpath(__file__)), "data", "CVE-2022-21824.json"
     )
-    with open(test_cve_data, "r") as fp:
+    with open(test_cve_data, mode="r", encoding="utf-8") as fp:
+        return json.loads(fp.read())
+
+
+@pytest.fixture
+def test_aqua_redhat3_json():
+    test_cve_data = os.path.join(
+        os.path.dirname(os.path.realpath(__file__)), "data", "CVE-2020-25638.json"
+    )
+    with open(test_cve_data, mode="r", encoding="utf-8") as fp:
         return json.loads(fp.read())
 
 
@@ -302,7 +402,7 @@ def test_aqua_arch_json():
     test_cve_data = os.path.join(
         os.path.dirname(os.path.realpath(__file__)), "data", "AVG-999.json"
     )
-    with open(test_cve_data, "r") as fp:
+    with open(test_cve_data, mode="r", encoding="utf-8") as fp:
         return json.loads(fp.read())
 
 
@@ -313,7 +413,7 @@ def test_aqua_opensuse_json():
         "data",
         "openSUSE-SU-2022-2801-1.json",
     )
-    with open(test_cve_data, "r") as fp:
+    with open(test_cve_data, mode="r", encoding="utf-8") as fp:
         return json.loads(fp.read())
 
 
@@ -322,7 +422,7 @@ def test_aqua_suse_json():
     test_cve_data = os.path.join(
         os.path.dirname(os.path.realpath(__file__)), "data", "SUSE-SU-2022-4192-1.json"
     )
-    with open(test_cve_data, "r") as fp:
+    with open(test_cve_data, mode="r", encoding="utf-8") as fp:
         return json.loads(fp.read())
 
 
@@ -331,7 +431,7 @@ def test_aqua_suse_json1():
     test_cve_data = os.path.join(
         os.path.dirname(os.path.realpath(__file__)), "data", "SUSE-SU-2015-0439-1.json"
     )
-    with open(test_cve_data, "r") as fp:
+    with open(test_cve_data, mode="r", encoding="utf-8") as fp:
         return json.loads(fp.read())
 
 
@@ -340,7 +440,7 @@ def test_aqua_photon_json():
     test_cve_data = os.path.join(
         os.path.dirname(os.path.realpath(__file__)), "data", "CVE-2021-3618.json"
     )
-    with open(test_cve_data, "r") as fp:
+    with open(test_cve_data, mode="r", encoding="utf-8") as fp:
         return json.loads(fp.read())
 
 
@@ -349,7 +449,7 @@ def test_aqua_debian_json():
     test_cve_data = os.path.join(
         os.path.dirname(os.path.realpath(__file__)), "data", "CVE-2019-18625.json"
     )
-    with open(test_cve_data, "r") as fp:
+    with open(test_cve_data, mode="r", encoding="utf-8") as fp:
         return json.loads(fp.read())
 
 
@@ -358,7 +458,7 @@ def test_aqua_debian2_json():
     test_cve_data = os.path.join(
         os.path.dirname(os.path.realpath(__file__)), "data", "CVE-2023-21500.json"
     )
-    with open(test_cve_data, "r") as fp:
+    with open(test_cve_data, mode="r", encoding="utf-8") as fp:
         return json.loads(fp.read())
 
 
@@ -367,7 +467,7 @@ def test_aqua_debian3_json():
     test_cve_data = os.path.join(
         os.path.dirname(os.path.realpath(__file__)), "data", "CVE-2022-3567.json"
     )
-    with open(test_cve_data, "r") as fp:
+    with open(test_cve_data, mode="r", encoding="utf-8") as fp:
         return json.loads(fp.read())
 
 
@@ -376,7 +476,7 @@ def test_aqua_debian4_json():
     test_cve_data = os.path.join(
         os.path.dirname(os.path.realpath(__file__)), "data", "DLA-981-1.json"
     )
-    with open(test_cve_data, "r") as fp:
+    with open(test_cve_data, mode="r", encoding="utf-8") as fp:
         return json.loads(fp.read())
 
 
@@ -385,7 +485,7 @@ def test_aqua_debian5_json():
     test_cve_data = os.path.join(
         os.path.dirname(os.path.realpath(__file__)), "data", "CVE-2021-22890.json"
     )
-    with open(test_cve_data, "r") as fp:
+    with open(test_cve_data, mode="r", encoding="utf-8") as fp:
         return json.loads(fp.read())
 
 
@@ -394,7 +494,7 @@ def test_aqua_debian6_json():
     test_cve_data = os.path.join(
         os.path.dirname(os.path.realpath(__file__)), "data", "CVE-2022-32091.json"
     )
-    with open(test_cve_data, "r") as fp:
+    with open(test_cve_data, mode="r", encoding="utf-8") as fp:
         return json.loads(fp.read())
 
 
@@ -403,7 +503,7 @@ def test_aqua_debian7_json():
     test_cve_data = os.path.join(
         os.path.dirname(os.path.realpath(__file__)), "data", "CVE-2020-35448.json"
     )
-    with open(test_cve_data, "r") as fp:
+    with open(test_cve_data, mode="r", encoding="utf-8") as fp:
         return json.loads(fp.read())
 
 
@@ -412,7 +512,7 @@ def test_aqua_cg_json():
     test_cve_data = os.path.join(
         os.path.dirname(os.path.realpath(__file__)), "data", "redis.json"
     )
-    with open(test_cve_data, "r") as fp:
+    with open(test_cve_data, mode="r", encoding="utf-8") as fp:
         return json.loads(fp.read())
 
 
@@ -421,7 +521,7 @@ def test_aqua_wolfi_json():
     test_cve_data = os.path.join(
         os.path.dirname(os.path.realpath(__file__)), "data", "protobuf-c.json"
     )
-    with open(test_cve_data, "r") as fp:
+    with open(test_cve_data, mode="r", encoding="utf-8") as fp:
         return json.loads(fp.read())
 
 
@@ -430,7 +530,7 @@ def test_aqua_alpine_unfixed_json():
     test_cve_data = os.path.join(
         os.path.dirname(os.path.realpath(__file__)), "data", "CVE-2024-25450.json"
     )
-    with open(test_cve_data, "r") as fp:
+    with open(test_cve_data, mode="r", encoding="utf-8") as fp:
         return json.loads(fp.read())
 
 
@@ -456,7 +556,7 @@ def test_convert(test_cve_json):
     results_count = len(
         list(search.search_by_any("cpe:2.3:o:google:android:8.1:*:*:*:*:*:*:*"))
     )
-    assert results_count == 25
+    assert results_count == 6
 
     cvesource = CVESource()
     cve = cvesource.convert5(vulnerabilities)
@@ -533,11 +633,11 @@ def test_nvd_api_convert(
     results_count = len(list(search.search_by_any("CVE-2020-8022")))
     assert results_count == 0
     results_count = len(list(search.search_by_any("CVE-2024-0057")))
-    assert results_count == 10
+    assert results_count == 20
     results_count = len(
         list(search.search_by_any("cpe:2.3:a:microsoft:.net:*:*:*:*:*:*:*:*"))
     )
-    assert results_count == 1
+    assert results_count == 3
 
     # json2
     vulnerabilities = nvdlatest.convert(test_nvd_api_json2)
@@ -592,7 +692,7 @@ def test_nvd_api_convert(
             )
         )
     )
-    assert results_count == 2
+    assert results_count == 1
 
     # git_json
     vulnerabilities = nvdlatest.convert(test_nvd_api_git_json)
@@ -616,6 +716,69 @@ def test_nvd_api_convert(
     assert results_count == 1
 
 
+def test_nvd_api_convert2(test_nvd_api_cpes_json):
+    nvdlatest = NvdSource()
+    #cpes_json
+    vulnerabilities = nvdlatest.convert(test_nvd_api_cpes_json)
+    assert len(vulnerabilities) == 1
+    assert len(vulnerabilities[0].details) == 2
+    db6.clear_all()
+    nvdlatest.store(vulnerabilities)
+    cve_data_count, cve_index_count = db6.stats()
+    assert cve_data_count == 1
+    assert cve_index_count == 1
+    results_count = len(list(search.search_by_any("CVE-2021-27434")))
+    assert results_count == 1
+    results_count = len(
+        list(
+            search.search_by_any(".net_based_opc_ua_client:server_sdk:*")
+        )
+    )
+    assert results_count == 1
+
+
+def test_nvd_api_convert3(test_nvd_api_signal_json):
+    db6.clear_all()
+    nvdlatest = NvdSource()
+    # signal ios
+    vulnerabilities = nvdlatest.convert(test_nvd_api_signal_json)
+    assert len(vulnerabilities) == 1
+    assert len(vulnerabilities[0].details) == 2
+    nvdlatest.store(vulnerabilities)
+    cve_data_count, cve_index_count = db6.stats()
+    assert cve_data_count == 2
+    assert cve_index_count == 2
+    results_count = len(list(search.search_by_any("CVE-2018-9840")))
+    assert results_count == 2
+    results_count = len(
+        list(
+            search.search_by_any("pkg:generic/ios/signal")
+        )
+    )
+    assert results_count == 1
+
+
+def test_nvd_api_convert4(test_nvd_api_at_json):
+    db6.clear_all()
+    nvdlatest = NvdSource()
+    # signal ios
+    vulnerabilities = nvdlatest.convert(test_nvd_api_at_json)
+    assert len(vulnerabilities) == 1
+    assert len(vulnerabilities[0].details) == 1
+    nvdlatest.store(vulnerabilities)
+    cve_data_count, cve_index_count = db6.stats()
+    assert cve_data_count == 1
+    assert cve_index_count == 1
+    results_count = len(list(search.search_by_any("CVE-2024-3801")))
+    assert results_count == 1
+    results_count = len(
+        list(
+            search.search_by_any("pkg:generic/conceptintermedia/s_m_cms")
+        )
+    )
+    assert results_count == 1
+
+
 @pytest.mark.skip(reason="This downloads and tests with live data")
 def test_nvd_download():
     nvdlatest = NvdSource()
@@ -648,7 +811,7 @@ def test_gha_version_ranges():
     version_list = source.get_version_range("< 1.10.2")
     assert version_list == ("", "", "", "1.10.2")
     version_list = source.get_version_range("= 0.2.0")
-    assert version_list == ("", "0.2.0", "", "")
+    assert version_list == ("0.2.0", "0.2.0", "", "")
     version_list = source.get_version_range("<= 1.0.8")
     assert version_list == ("", "1.0.8", "", "")
     version_list = source.get_version_range(">= 4.3.0, < 4.3.5")
@@ -665,6 +828,8 @@ def test_gha_version_ranges():
     assert version_list == ("1.1.0", "", "", "")
     version_list = source.get_version_range("> 11.0, < 24.1.1")
     assert version_list == ("", "", "11.0", "24.1.1")
+    version_list = source.get_version_range("= 6.1.2")
+    assert version_list == ("6.1.2", "6.1.2", "", "")
 
 
 @pytest.mark.skip(reason="This downloads and tests with live data")
@@ -676,9 +841,13 @@ def test_osv_download_all():
 
 def test_osv_convert(
     test_osv_rust_json,
+    test_osv_rust2_json,
+    test_osv_rust3_json,
     test_osv_mvn_json,
     test_osv_mixed_json,
     test_osv_go_json,
+    test_osv_go2_json,
+    test_osv_go3_json,
     test_osv_pypi_json,
     test_osv_pypi2_json,
     test_osv_pypi3_json,
@@ -702,12 +871,18 @@ def test_osv_convert(
     results_count = len(list(search.search_by_any("CVE-2020-8022")))
     assert results_count == 0
     results_count = len(list(search.search_by_any("CVE-2019-0647")))
-    assert results_count == 2
-    results_count = len(list(search.search_by_any("pkg:maven/org.springframework/spring-web")))
+    assert results_count == 5
+    results_count = len(
+        list(search.search_by_any("pkg:maven/org.springframework/spring-web"))
+    )
     assert results_count == 0
-    results_count = len(list(search.search_by_any("pkg:apk/alpine/mariadb?arch=source")))
+    results_count = len(
+        list(search.search_by_any("pkg:apk/alpine/mariadb?arch=source"))
+    )
     assert results_count == 0
-    results_count = len(list(search.search_by_any("pkg:apk/alpine/alpine-3.2/mariadb?arch=source")))
+    results_count = len(
+        list(search.search_by_any("pkg:apk/alpine/alpine-3.2/mariadb?arch=source"))
+    )
     assert results_count == 1
 
     # multi events
@@ -723,10 +898,14 @@ def test_osv_convert(
     results_count = len(list(search.search_by_any("CVE-2020-8022")))
     assert results_count == 0
     results_count = len(list(search.search_by_any("CVE-2019-3192")))
-    assert results_count == 1
-    results_count = len(list(search.search_by_any("pkg:apk/alpine/mariadb?arch=source")))
+    assert results_count == 4
+    results_count = len(
+        list(search.search_by_any("pkg:apk/alpine/mariadb?arch=source"))
+    )
     assert results_count == 0
-    results_count = len(list(search.search_by_any("pkg:maven/org.springframework/spring-web")))
+    results_count = len(
+        list(search.search_by_any("pkg:maven/org.springframework/spring-web"))
+    )
     assert results_count == 4
 
     # swift
@@ -758,17 +937,45 @@ def test_osv_convert(
     # rust
     cve_data = osvlatest.convert(test_osv_rust_json)
     assert cve_data
-
     db6.clear_all()
     osvlatest.store(cve_data)
     cve_data_count, cve_index_count = db6.stats()
     assert cve_data_count == 1
     assert cve_index_count == 1
-    results_count = len(list(search.search_by_any("pkg:apk/alpine/mariadb?arch=source")))
+    results_count = len(
+        list(search.search_by_any("pkg:apk/alpine/mariadb?arch=source"))
+    )
     assert results_count == 0
     results_count = len(list(search.search_by_any("pkg:cargo/rusqlite")))
     assert results_count == 1
 
+    cve_data = osvlatest.convert(test_osv_rust2_json)
+    assert cve_data
+    assert cve_data[0].affects == {
+        "affected_functions": ["nano_id::base58", "nano_id::base62", "nano_id::gen"],
+        "affected_modules": ["nano_id"],
+    }
+    cve_data = osvlatest.convert(test_osv_rust3_json)
+    assert cve_data
+    assert cve_data[0].affects == {
+        "affected_functions": [
+            "lettre::sendmail::SendmailTransport::send",
+            "lettre::transport::sendmail::SendmailTransport::send",
+            "lettre::transport::sendmail::SendmailTransport::send_raw",
+        ],
+        "affected_modules": [
+            "lettre::sendmail::SendmailTransport",
+            "lettre::transport::sendmail::SendmailTransport",
+        ],
+    }
+    db6.clear_all()
+    osvlatest.store(cve_data)
+    cve_data_count, cve_index_count = db6.stats()
+    assert cve_data_count == 3
+    assert cve_index_count == 3
+    results_count = len(list(search.search_by_any("pkg:cargo/lettre")))
+    assert results_count == 3
+
     # maven
     cve_data = osvlatest.convert(test_osv_mvn_json)
     assert cve_data
@@ -793,13 +1000,12 @@ def test_osv_convert(
     results_count = len(list(search.search_by_any("CVE-2020-8022")))
     assert results_count == 0
     results_count = len(list(search.search_by_any("CVE-2021-23440")))
-    assert results_count == 2
+    assert results_count == 3
 
     # go
     cve_data = osvlatest.convert(test_osv_go_json)
     assert cve_data
     assert len(cve_data) == 1
-
     db6.clear_all()
     osvlatest.store(cve_data)
     cve_data_count, cve_index_count = db6.stats()
@@ -809,6 +1015,25 @@ def test_osv_convert(
     assert results_count == 0
     results_count = len(list(search.search_by_any("CVE-2020-8911")))
     assert results_count == 1
+    cve_data = osvlatest.convert(test_osv_go2_json)
+    assert cve_data
+    assert len(cve_data) == 1
+    assert cve_data[0].affects == {
+        "affected_functions": [
+            "BER2DER",
+            "DecodeManifest",
+            "DecoderConfig.DecodeManifest",
+            "readObject",
+        ],
+        "affected_modules": ["github.com/cloudflare/cfrpki/validator/lib"],
+    }
+    cve_data = osvlatest.convert(test_osv_go3_json)
+    assert cve_data
+    assert len(cve_data) == 2
+    assert cve_data[0].affects == {
+        "affected_functions": ["Server.ServeConn"],
+        "affected_modules": [],
+    }
 
     # pypi
     cve_data = osvlatest.convert(test_osv_pypi_json)
@@ -841,8 +1066,26 @@ def test_osv_convert2(test_osv_npm_star_json):
     assert len(cve_data) == 3
 
 
-def test_osv_mal_convert(test_osv_mal_json):
+def test_osv_convert3(test_osv_mvn_single_json):
     osvlatest = OSVSource()
+
+    # maven single version
+    cve_data = osvlatest.convert(test_osv_mvn_single_json)
+    assert len(cve_data) == 2
+
+
+def test_osv_convert4(test_osv_maven_cvss4_json):
+    osvlatest = OSVSource()
+
+    # maven cvss4 version
+    cve_data = osvlatest.convert(test_osv_maven_cvss4_json)
+    assert len(cve_data) == 6
+
+
+def test_osv_mal_convert(test_osv_mal_json, test_osv_mal2_json):
+    osvlatest = OSVSource()
+    cve_data = osvlatest.convert(test_osv_mal2_json)
+    assert len(cve_data) == 1
     cve_data = osvlatest.convert(test_osv_mal_json)
     assert len(cve_data) == 1
 
@@ -857,6 +1100,7 @@ def test_aqua_convert(
     test_aqua_ubuntu3_json,
     test_aqua_redhat_json,
     test_aqua_redhat2_json,
+    test_aqua_redhat3_json,
     test_aqua_arch_json,
     test_aqua_opensuse_json,
     test_aqua_suse_json,
@@ -922,7 +1166,7 @@ def test_aqua_convert(
     results_count = len(list(search.search_by_any("CVE-2020-8022")))
     assert results_count == 0
     results_count = len(list(search.search_by_any("CVE-2022-45406")))
-    assert results_count == 26
+    assert results_count == 27
 
     # ubuntu1
     cve_data = aqualatest.convert(test_aqua_ubuntu1_json)
@@ -996,6 +1240,18 @@ def test_aqua_convert(
     results_count = len(list(search.search_by_any("CVE-2022-21824")))
     assert results_count == 7
 
+    # redhat3
+    cve_data = aqualatest.convert(test_aqua_redhat3_json)
+    assert cve_data
+    assert len(cve_data) == 73
+    db6.clear_all()
+    aqualatest.store(cve_data)
+    cve_data_count, cve_index_count = db6.stats()
+    assert cve_data_count == 73
+    assert cve_index_count == 73
+    results_count = len(list(search.search_by_any("CVE-2020-25638")))
+    assert results_count == 73
+
     # arch
     cve_data = aqualatest.convert(test_aqua_arch_json)
     assert cve_data
@@ -1031,12 +1287,12 @@ def test_aqua_convert(
     db6.clear_all()
     aqualatest.store(cve_data)
     cve_data_count, cve_index_count = db6.stats()
-    assert cve_data_count == 1
-    assert cve_index_count == 1
+    assert cve_data_count == 4
+    assert cve_index_count == 4
     results_count = len(list(search.search_by_any("CVE-2020-8022")))
     assert results_count == 0
     results_count = len(list(search.search_by_any("CVE-2021-3618")))
-    assert results_count == 1
+    assert results_count == 4
 
     # suse1
     cve_data = aqualatest.convert(test_aqua_suse_json1)
