@@ -1,4 +1,4 @@
-from vdb.lib import utils as utils
+from vdb.lib import utils
 
 
 def test_normalise():
@@ -225,7 +225,7 @@ def test_version_build_compare():
 
 
 def test_version_build_compare1():
-    sver, srest = utils.convert_to_semver("2.1.5.1-r3")
+    sver, _ = utils.convert_to_semver("2.1.5.1-r3")
     assert sver
     res = utils.version_compare("2.1.5.1-r3", "1.2.1-r0", "2.1.5.1-r1")
     assert not res
@@ -631,7 +631,7 @@ v0.3.7 0.3.8
 
 
 def test_parse_uri():
-    vendor, package, version, cve_type = utils.parse_cpe(
+    vendor, package, version, _ = utils.parse_cpe(
         "cpe:2.3:o:google:android:9.0:*:*:*:*:*:*:*"
     )
     assert vendor == "google"
@@ -888,6 +888,42 @@ def test_purl_vers_convert():
             ],
             "vers:deb/53.5",
         ),
+        (
+            "generic",
+            [
+                {
+                    "version": "0.0.0",
+                    "status": "affected",
+                    "versionType": "generic",
+                    "lessThan": "001a3278b5572e52c0ecac0bd1157bf2599502b7",
+                }
+            ],
+            "vers:generic/<001a3278b5572e52c0ecac0bd1157bf2599502b7",
+        ),
+        (
+            "cisco",
+            [
+                {
+                    "version": r"6.3\(1\)",
+                    "status": "affected",
+                    "versionType": "cisco",
+                    "lessThanOrEqual": r"6.3\(1\)",
+                }
+            ],
+            "vers:cisco/6.3-1",
+        ),
+        (
+            "maven",
+            [
+                {
+                    "version": r"6.0.15",
+                    "status": "affected",
+                    "versionType": "maven",
+                    "lessThanOrEqual": r"6.0.15",
+                }
+            ],
+            "vers:maven/6.0.15",
+        ),
     ]
     for tt in test_tuples:
         assert utils.to_purl_vers(tt[0], tt[1]) == tt[2]
@@ -992,6 +1028,16 @@ def test_url_to_purl():
         "qualifiers": None,
         "subpath": None,
     }
+    assert utils.url_to_purl(
+        "https://www.github.com/kiwitcms/kiwi/commit/ffb00450be52fe11a82a2507632c2328cae4ec9d"
+    ) == {
+        "type": "github",
+        "namespace": "kiwitcms",
+        "name": "kiwi",
+        "version": "ffb00450be52fe11a82a2507632c2328cae4ec9d",
+        "qualifiers": None,
+        "subpath": None,
+    }
 
 
 def test_vers_compare():
@@ -1000,3 +1046,37 @@ def test_vers_compare():
     assert not utils.vers_compare("1.13.0", "vers:rpm/<=1.12.8-24.el8_8.1")
     assert utils.vers_compare("5.5", "vers:deb/<5.6~rc2")
     assert not utils.vers_compare("5.7", "vers:deb/<5.6~rc2")
+    assert not utils.vers_compare("6.0.13", "vers:maven/6.0.15")
+    assert not utils.vers_compare("6.0.13", "vers:maven/6.1.2")
+    assert not utils.vers_compare("6.0.13", "vers:maven/6.1.2")
+    assert not utils.vers_compare("6.0.13", "vers:maven/>=4.2.0.RELEASE|<4.3.20.RELEASE")
+    assert not utils.vers_compare("6.0.13", "vers:maven/>=5.0.0.RELEASE|<5.0.10.RELEASE")
+    assert not utils.vers_compare("6.0.13", "vers:maven/>=5.1.0.RELEASE|<5.1.1.RELEASE")
+    assert not utils.vers_compare("6.0.13", "vers:maven/>=4.3.0.RELEASE|<4.3.18.RELEASE")
+    assert not utils.vers_compare("6.0.13", "vers:maven/>=5.0.0.RELEASE|<5.0.7.RELEASE")
+    assert utils.vers_compare("1.12", "")
+
+
+
+def test_clean_cpe_uri():
+    test_tuples = (
+        [None, None],
+        ["cpe:2.3:a:unified-automation:.net_based_opc_ua_client\\/server_sdk:*:*:*:*:*:*:*:*", "cpe:2.3:a:unified-automation:.net_based_opc_ua_client/server_sdk:*:*:*:*:*:*:*:*"],
+        ["cpe:2.3:a:cisco:dna_spaces\\:_connector:*:*:*:*:*:*:*:*", "cpe:2.3:a:cisco:dna_spaces:_connector:*:*:*:*:*:*:*:*"],
+        ["cpe:2.3:a:trendmicro:antivirus_\\+_security_2019:15.0:*:*:*:*:*:*:*", "cpe:2.3:a:trendmicro:antivirus_security_2019:15.0:*:*:*:*:*:*:*"],
+        ["cpe:2.3:a:eleopard:animate_it\\!:*:*:*:*:*:wordpress:*:*", "cpe:2.3:a:eleopard:animate_it:*:*:*:*:*:wordpress:*:*"],
+        ["cpe:2.3:a:icegram:email_subscribers_\\\u0026_newsletters:*:*:*:*:*:wordpress:*:*", "cpe:2.3:a:icegram:email_subscribers_newsletters:*:*:*:*:*:wordpress:*:*"],
+        ["cpe:2.3:a:display_post_meta,_term_meta,_comment_meta,_and_user_meta_project/display_post_meta,_term_meta,_comment_meta,_and_user_meta", "cpe:2.3:a:display_post_meta_term_meta_comment_meta_and_user_meta_project/display_post_meta_term_meta_comment_meta_and_user_meta"],
+        ["cpe:2.3:a:[gwa]_autoresponder_project/[gwa]_autoresponder", "cpe:2.3:a:gwa_autoresponder_project/gwa_autoresponder"]
+    )
+    for tt in test_tuples:
+        assert utils.clean_cpe_uri(tt[0]) == tt[1]
+
+
+def test_extract_affected_symbols():
+    assert utils.extract_affected_symbols(
+        "Format string vulnerability in startprinting() function of printjob.c in BSD-based lpr lpd package may allow local users to gain privileges via an improper syslog call that uses format strings from the checkremote() call.") == {
+               'affected_functions': ['checkremote', 'startprinting'], 'affected_modules': ['printjob']}
+    assert utils.extract_affected_symbols(
+        "The print_attr_string function in print-radius.c for tcpdump 3.8.1 and earlier allows remote attackers to cause a denial of service (segmentation fault) via a RADIUS attribute with a large length value.") == {
+               'affected_functions': ['print_attr_string'], 'affected_modules': ['print-radius']}
