@@ -104,7 +104,7 @@ PKG_TYPES_MAP = {
     "composer": ["php", "laravel", "wordpress", "joomla"],
     "maven": ["jenkins", "java", "kotlin", "groovy", "clojars", "hackage"],
     "npm": ["javascript", "node.js", "nodejs", "npmjs"],
-    "nuget": [".net_framework", "csharp", ".net_core", "asp.net"],
+    "nuget": [".net_framework", "csharp", ".net_core", "asp.net", "c#"],
     "pypi": ["python"],
     "gem": ["ruby"],
     "rubygems": ["ruby", "gem"],
@@ -127,7 +127,10 @@ PKG_TYPES_MAP = {
         "fedoraproject"
     ],
     "alpm": ["arch", "archlinux"],
-    "ebuild": ["gentoo", "portage"]
+    "ebuild": ["gentoo", "portage"],
+    "ios": ["iphoneos", "iphone_os"],
+    "vscode": ["vs_code", "visual_studio_code"],
+    "macos": ["mac_os_x", "osx"]
 }
 
 # CPE Regex
@@ -493,6 +496,7 @@ class Vulnerability:
     """Vulnerability"""
 
     cvss_v3: CvssV3
+    cvss4_vector_string: str | None
 
     def __init__(
             self,
@@ -507,6 +511,7 @@ class Vulnerability:
             cvss_v3: CvssV3,
             source_update_time: str,
             source_orig_time: str,
+            affects: dict = None,
     ):
         self.id = vid
         self.assigner = assigner
@@ -519,6 +524,8 @@ class Vulnerability:
         self.cvss_v3 = cvss_v3
         self.source_update_time: datetime = convert_time(source_update_time)
         self.source_orig_time: datetime = convert_time(source_orig_time)
+        self.affects = affects
+        self.cvss4_vector_string = None
 
     def __repr__(self):
         return orjson.dumps(
@@ -536,6 +543,8 @@ class Vulnerability:
                     "%Y-%m-%dT%H:%M:%S"
                 ),
                 "source_orig_time": self.source_orig_time.strftime("%Y-%m-%dT%H:%M:%S"),
+                "affects": self.affects,
+                "cvss4_vector_string": self.cvss4_vector_string
             },
             option=orjson.OPT_NAIVE_UTC,
         ).decode("utf-8", "ignore")
