@@ -5,6 +5,7 @@ This module fetches the vulnerability data from aquasec vuln-list repo and store
 """
 
 import os
+
 from datetime import datetime
 from zipfile import ZipFile
 
@@ -23,6 +24,49 @@ from vdb.lib.utils import (
 # Size of the stream to read and write to the file
 DOWNLOAD_CHUNK_SIZE = 4096
 
+# Some sources are included by default
+DEFAULT_INCLUDE_SOURCE_PATTERNS = ["alpine-unfixed"] if os.getenv("VDB_IGNORE_ALPINE", "") not in ("true", "1") else []
+
+# Some sources are ignored by default
+DEFAULT_IGNORE_SOURCE_PATTERNS = [
+    "alpine",
+    "cwe",
+    "ghsa",
+    "go",
+    "osv",
+    "redhat-cpe",
+    "kevc",
+    "oval",
+    "glad",
+    "mariner",
+]
+
+# Suse is ignored by default for performance reasons
+if os.getenv("VDB_INCLUDE_SUSE", "") not in ("true", "1"):
+    DEFAULT_IGNORE_SOURCE_PATTERNS.append(f"cvrf{os.sep}suse{os.sep}suse")
+
+
+def get_include_source_patterns():
+    """
+    Constructs include patterns by looking up certain distro-specific environment variables
+    """
+    include_paths = DEFAULT_INCLUDE_SOURCE_PATTERNS
+    for name, paths in config.LINUX_DISTRO_VULN_LIST_PATHS.items():
+        if os.getenv(f"VDB_INCLUDE_{name.upper()}", "") in ("true", "1"):
+            include_paths += paths
+    return include_paths
+
+
+def get_ignored_source_patterns():
+    """
+    Constructs ignore patterns by looking up certain distro-specific environment variables
+    """
+    ignore_paths = DEFAULT_IGNORE_SOURCE_PATTERNS
+    for name, paths in config.LINUX_DISTRO_VULN_LIST_PATHS.items():
+        if os.getenv(f"VDB_IGNORE_{name.upper()}", "") in ("true", "1") or os.getenv(f"VDB_EXCLUDE_{name.upper()}", "") in ("true", "1"):
+            ignore_paths += paths
+    return ignore_paths
+
 
 class AquaSource(NvdSource):
     """Aqua CVE source"""
@@ -96,27 +140,18 @@ class AquaSource(NvdSource):
 
     @staticmethod
     def is_supported_source(zfname):
-        for distro in ("alpine-unfixed",):
+        # Include has preference over ignore
+        for distro in get_include_source_patterns():
             if distro in zfname:
                 return True
-        for distro in (
-            "alpine",
-            "cwe",
-            "ghsa",
-            "go",
-            "osv",
-            "redhat-cpe",
-            "kevc",
-            "oval",
-            "glad",
-            "mariner",
-        ):
+        for distro in get_ignored_source_patterns():
             if distro in zfname:
                 return False
         nvd_start_year = config.NVD_START_YEAR
         for year in range(1999, nvd_start_year):
-            if f"CVE-{year}-" in zfname:
-                return False
+            for pat in (f"CVE-{year}-", f"{os.sep}{year}{os.sep}", f"ALAS-{year}-", f"ALAS2-{year}-", f"openSUSE-SU-{year}-"):
+                if pat in zfname:
+                    return False
         if zfname.endswith(".json"):
             return True
         return False
@@ -134,13 +169,14 @@ class AquaSource(NvdSource):
         cwe_id = ""
         cve_references = cve_data.get("references", [])
         references = []
-        for aref in cve_references:
-            references.append(
-                {"name": aref.get("title", "id"), "url": aref.get("href")}
-            )
-        references = orjson.dumps(references, option=orjson.OPT_NAIVE_UTC)
-        if isinstance(references, bytes):
-            references = references.decode("utf-8", "ignore")
+        if cve_references:
+            for aref in cve_references:
+                references.append(
+                    {"name": aref.get("title", "id"), "url": aref.get("href")}
+                )
+            references = orjson.dumps(references, option=orjson.OPT_NAIVE_UTC)
+            if isinstance(references, bytes):
+                references = references.decode("utf-8", "ignore")
         description = cve_data.get("description", "")
         if not description and cve_data.get("title"):
             description = f"""# {cve_data.get("summary")}
@@ -210,8 +246,9 @@ class AquaSource(NvdSource):
             )
             try:
                 vuln = NvdSource.convert_vuln(orjson.loads(tdata))
-                vuln.description = compress_str(description)
-                ret_data.append(vuln)
+                if vuln:
+                    vuln.description = compress_str(description)
+                    ret_data.append(vuln)
             except Exception:
                 pass
         return ret_data
@@ -227,11 +264,12 @@ class AquaSource(NvdSource):
         cwe_id = ""
         cve_references = cve_data.get("references", [])
         references = []
-        for aref in cve_references:
-            references.append({"name": aref.get("id"), "url": aref.get("href")})
-        references = orjson.dumps(references, option=orjson.OPT_NAIVE_UTC)
-        if isinstance(references, bytes):
-            references = references.decode("utf-8", "ignore")
+        if cve_references:
+            for aref in cve_references:
+                references.append({"name": aref.get("id"), "url": aref.get("href")})
+            references = orjson.dumps(references, option=orjson.OPT_NAIVE_UTC)
+            if isinstance(references, bytes):
+                references = references.decode("utf-8", "ignore")
         if not cve_id.startswith("CVE") and cve_data.get("cveids"):
             cve_id = cve_data.get("cveids")[0]
         description = cve_data.get("description", "")
@@ -293,6 +331,8 @@ class AquaSource(NvdSource):
                 )
                 try:
                     vuln = NvdSource.convert_vuln(orjson.loads(tdata))
+                    if vuln is None:
+                        continue
                     vuln.description = compress_str(description)
                     ret_data.append(vuln)
                     done_pkgs[pkg_key] = True
@@ -311,11 +351,12 @@ class AquaSource(NvdSource):
         cwe_id = ""
         cve_references = cve_data.get("References", [])
         references = []
-        for aref in cve_references:
-            references.append({"name": aref, "url": aref})
-        references = orjson.dumps(references, option=orjson.OPT_NAIVE_UTC)
-        if isinstance(references, bytes):
-            references = references.decode("utf-8", "ignore")
+        if cve_references:
+            for aref in cve_references:
+                references.append({"name": aref, "url": aref})
+            references = orjson.dumps(references, option=orjson.OPT_NAIVE_UTC)
+            if isinstance(references, bytes):
+                references = references.decode("utf-8", "ignore")
         description = cve_data.get("Description")
         if "** DISPUTED **" in description or "** REJECT **" in description:
             return ret_data
@@ -396,6 +437,8 @@ class AquaSource(NvdSource):
                         )
                         try:
                             vuln = NvdSource.convert_vuln(orjson.loads(tdata))
+                            if vuln is None:
+                                continue
                             vuln.description = compress_str(description)
                             ret_data.append(vuln)
                         except Exception:
@@ -409,19 +452,28 @@ class AquaSource(NvdSource):
         cvss3 = cve_data.get("cvss3", {})
         if cvss3.get("status") is not None and cvss3.get("status") != "verified":
             return ret_data
+        ignore_cpes = {}
         packages = cve_data.get("affected_release", [])
+        package_state = cve_data.get("package_state", [])
+        if package_state:
+            for ps in package_state:
+                fix_state = ps.get("fix_state")
+                cpe = ps.get("cpe")
+                if fix_state and fix_state.lower() != "affected":
+                    ignore_cpes[cpe] = True
         if not packages or not len(packages) > 0:
             return ret_data
         cve_id = cve_data.get("name")
         cwe_id = cve_data.get("cwe")
         cve_references = cve_data.get("references", "")
         references = []
-        for aref in cve_references:
-            for bref in aref.split("\n"):
-                references.append({"name": bref, "url": bref})
-        references = orjson.dumps(references, option=orjson.OPT_NAIVE_UTC)
-        if isinstance(references, bytes):
-            references = references.decode("utf-8", "ignore")
+        if cve_references:
+            for aref in cve_references:
+                for bref in aref.split("\n"):
+                    references.append({"name": bref, "url": bref})
+            references = orjson.dumps(references, option=orjson.OPT_NAIVE_UTC)
+            if isinstance(references, bytes):
+                references = references.decode("utf-8", "ignore")
         description = "\n".join(cve_data.get("details", []))
         assigner = "redhat"
         vector_string = cvss3.get("cvss3_scoring_vector")
@@ -446,9 +498,11 @@ class AquaSource(NvdSource):
         done_pkgs = {}
         for arelease in packages:
             pkg_key = arelease.get("package")
-            if done_pkgs.get(pkg_key):
+            cpe = arelease.get("cpe", "")
+            # Ignore CPEs that are out of support or won't be fixed
+            if ignore_cpes.get(cpe) or done_pkgs.get(pkg_key):
                 continue
-            tmp_a = pkg_key.split(":" if ":" in pkg_key else "-")
+            tmp_a = pkg_key.split(":")
             if len(tmp_a) < 2:
                 continue
             pkg_name = tmp_a[0]
@@ -457,12 +511,11 @@ class AquaSource(NvdSource):
             if ":" in pkg_key:
                 version = pkg_key.split(":")[-1]
             else:
-                version = pkg_key.replace(pkg_name + "-", "")
+                continue
             # Remove epoch
             if ":" in version:
                 version = version.split(":")[-1]
             edition = "*"
-            cpe = arelease.get("cpe", "")
             if cpe and cpe.startswith("cpe:"):
                 tmpc = cpe.split(":")
                 if len(tmpc) > 2:
@@ -507,6 +560,8 @@ class AquaSource(NvdSource):
                 )
                 try:
                     vuln = NvdSource.convert_vuln(orjson.loads(tdata))
+                    if vuln is None:
+                        continue
                     vuln.description = compress_str(description)
                     ret_data.append(vuln)
                     done_pkgs[pkg_key] = True
@@ -573,6 +628,8 @@ class AquaSource(NvdSource):
                 )
                 try:
                     vuln = NvdSource.convert_vuln(orjson.loads(tdata))
+                    if vuln is None:
+                        continue
                     vuln.description = compress_str(description)
                     ret_data.append(vuln)
                 except Exception:
@@ -594,6 +651,8 @@ class AquaSource(NvdSource):
     def suse_to_vuln(self, cve_data):
         """Suse Linux"""
         ret_data = []
+        tracking_id = cve_data.get("Tracking", {}).get("ID", "")
+        assigner = "opensuse" if "opensuse" in tracking_id.lower() else "suse"
         packages = cve_data.get("ProductTree", {}).get("Relationships", [])
         if not packages or not len(packages) > 0:
             return ret_data
@@ -613,14 +672,14 @@ class AquaSource(NvdSource):
                 cwe_id = ""
                 cve_references = avuln.get("References", [])
                 references = []
-                for aref in cve_references:
-                    references.append(
-                        {"name": aref.get("Description", "id"), "url": aref.get("URL")}
-                    )
-                references = orjson.dumps(references, option=orjson.OPT_NAIVE_UTC)
-                if isinstance(references, bytes):
-                    references = references.decode("utf-8", "ignore")
-                assigner = "suse"
+                if cve_references:
+                    for aref in cve_references:
+                        references.append(
+                            {"name": aref.get("Description", "id"), "url": aref.get("URL")}
+                        )
+                    references = orjson.dumps(references, option=orjson.OPT_NAIVE_UTC)
+                    if isinstance(references, bytes):
+                        references = references.decode("utf-8", "ignore")
                 (
                     score,
                     severity,
@@ -628,54 +687,63 @@ class AquaSource(NvdSource):
                     attack_complexity,
                 ) = get_default_cve_data(severity)
                 done_pkgs = {}
-                for pref in packages:
-                    pkg_key = pref.get("ProductReference")
-                    if done_pkgs.get(pkg_key):
+                product_statuses = avuln.get("ProductStatuses", [])
+                for aps in product_statuses:
+                    if aps.get("Type") != "Fixed":
                         continue
-                    pkg_name, version = self.product_ref_to_name_version(pkg_key)
-                    version_start_including = ""
-                    version_end_including = ""
-                    version_start_excluding = ""
-                    version_end_excluding = version
-                    fix_version_end_including = ""
-                    fix_version_start_excluding = ""
-                    fix_version_end_excluding = ""
-                    fix_version_start_including = version
-                    if pkg_name and version:
-                        tdata = config.CVE_TPL % dict(
-                            cve_id=cve_id,
-                            cwe_id=cwe_id,
-                            assigner=assigner,
-                            references=references,
-                            description="",
-                            vectorString=vector_string,
-                            vendor="rpm",
-                            product=f"suse/{pkg_name}",
-                            version="*",
-                            edition="*",
-                            version_start_including=version_start_including,
-                            version_end_including=version_end_including,
-                            version_start_excluding=version_start_excluding,
-                            version_end_excluding=version_end_excluding,
-                            fix_version_start_including=fix_version_start_including,
-                            fix_version_end_including=fix_version_end_including,
-                            fix_version_start_excluding=fix_version_start_excluding,
-                            fix_version_end_excluding=fix_version_end_excluding,
-                            severity=severity,
-                            attackComplexity=attack_complexity,
-                            score=score,
-                            userInteraction="REQUIRED",
-                            exploitabilityScore=score,
-                            publishedDate=published_date,
-                            lastModifiedDate=last_modified_date,
-                        )
-                        try:
-                            vuln = NvdSource.convert_vuln(orjson.loads(tdata))
-                            vuln.description = compress_str(description)
-                            ret_data.append(vuln)
-                            done_pkgs[pkg_key] = True
-                        except Exception:
-                            pass
+                    product_ids = aps.get("ProductID")
+                    if not product_ids:
+                        continue
+                    for pkg_key in product_ids:
+                        if done_pkgs.get(pkg_key):
+                            continue
+                        pkg_name, version = self.product_ref_to_name_version(pkg_key)
+                        pkg_name = pkg_name.lower().replace(" ", "-").replace(":", "/")
+                        version_start_including = ""
+                        version_end_including = ""
+                        version_start_excluding = ""
+                        version_end_excluding = version
+                        fix_version_end_including = ""
+                        fix_version_start_excluding = ""
+                        fix_version_end_excluding = ""
+                        fix_version_start_including = version
+                        if pkg_name and version:
+                            tdata = config.CVE_TPL % dict(
+                                cve_id=cve_id,
+                                cwe_id=cwe_id,
+                                assigner=assigner,
+                                references=references,
+                                description="",
+                                vectorString=vector_string,
+                                vendor="rpm",
+                                product=pkg_name,
+                                version="*",
+                                edition="*",
+                                version_start_including=version_start_including,
+                                version_end_including=version_end_including,
+                                version_start_excluding=version_start_excluding,
+                                version_end_excluding=version_end_excluding,
+                                fix_version_start_including=fix_version_start_including,
+                                fix_version_end_including=fix_version_end_including,
+                                fix_version_start_excluding=fix_version_start_excluding,
+                                fix_version_end_excluding=fix_version_end_excluding,
+                                severity=severity,
+                                attackComplexity=attack_complexity,
+                                score=score,
+                                userInteraction="REQUIRED",
+                                exploitabilityScore=score,
+                                publishedDate=published_date,
+                                lastModifiedDate=last_modified_date,
+                            )
+                            try:
+                                vuln = NvdSource.convert_vuln(orjson.loads(tdata))
+                                if vuln is None:
+                                    continue
+                                vuln.description = compress_str(description)
+                                ret_data.append(vuln)
+                                done_pkgs[pkg_key] = True
+                            except Exception:
+                                pass
         return ret_data
 
     @staticmethod
@@ -741,8 +809,9 @@ class AquaSource(NvdSource):
             )
             try:
                 vuln = NvdSource.convert_vuln(orjson.loads(tdata))
-                vuln.description = compress_str(description)
-                ret_data.append(vuln)
+                if vuln:
+                    vuln.description = compress_str(description)
+                    ret_data.append(vuln)
             except Exception:
                 pass
         return ret_data
@@ -859,6 +928,8 @@ class AquaSource(NvdSource):
                 )
                 try:
                     vuln = NvdSource.convert_vuln(orjson.loads(tdata))
+                    if vuln is None:
+                        continue
                     vuln.description = compress_str(description)
                     ret_data.append(vuln)
                 except Exception:
@@ -924,6 +995,8 @@ class AquaSource(NvdSource):
                 )
                 try:
                     vuln = NvdSource.convert_vuln(orjson.loads(tdata))
+                    if vuln is None:
+                        continue
                     vuln.description = f"""URL Prefix: {cve_data.get("urlprefix")}. Affected arch: {", ".join(cve_data.get("archs"))}"""
                     ret_data.append(vuln)
                 except Exception:
@@ -978,6 +1051,8 @@ class AquaSource(NvdSource):
             )
             try:
                 vuln = NvdSource.convert_vuln(orjson.loads(tdata))
+                if vuln is None:
+                    continue
                 vuln.description = f"{cve_id} is unfixed in {edition}. Visit https://security.alpinelinux.org/vuln/{cve_id} for more details."
                 ret_data.append(vuln)
             except Exception:
