@@ -1,5 +1,6 @@
 import base64
 import os
+import re
 import uuid
 
 import orjson
@@ -33,9 +34,12 @@ from vdb.lib.cve_model import (
     Metrics,
     Metrics1,
     Metrics2,
+    Metrics3,
+    Module,
     OrgId,
     ProblemType,
     ProblemTypes,
+    ProgramRoutine,
     Product,
     ProviderMetadata,
     Reference,
@@ -47,9 +51,10 @@ from vdb.lib.cve_model import (
     Version,
     Versions,
 )
-from vdb.lib.cve_model.common import CiaType
+from vdb.lib.cve_model.common import CiaType, SubCiaType
 from vdb.lib.cve_model.cvss_v3 import Field0, Field1
-from vdb.lib.utils import calculate_hash, to_purl_vers
+from vdb.lib.cve_model.cvss_v4 import Field0Model6
+from vdb.lib.utils import calculate_hash, get_cvss4_from_vector, to_purl_vers
 
 # Our DB creation process could result in duplicates. By tracking these keys we reduce them
 source_completed_keys = {}
@@ -67,11 +72,14 @@ def to_cve_metadata(avuln: Vulnerability):
             ASSIGNER_UUID_MAP[avuln.assigner] = assigner_org_id
     else:
         assigner_org_id = OrgId(UuidType(str(uuid.uuid4())))
+    assigner_short_name = avuln.assigner
+    if assigner_short_name and len(assigner_short_name) > 32:
+        assigner_short_name = assigner_short_name[0:31]
     metadata = CveMetadataPublished(
         cveId=CveId(avuln.id),
         state=State.PUBLISHED,
         assignerOrgId=assigner_org_id,
-        assignerShortName=avuln.assigner,
+        assignerShortName=assigner_short_name,
     )
     metadata.datePublished = avuln.source_orig_time
     metadata.dateUpdated = avuln.source_update_time
@@ -162,6 +170,14 @@ def to_product_versions(vendor, adetail: VulnerabilityDetail) -> list[Versions]:
     return versions
 
 
+def clean_vendor_product(s):
+    if not s:
+        return s
+    s = s.removeprefix("_").removesuffix("_")
+    s = re.sub(r"[&,()+]", "", s)
+    return s
+
+
 def to_cve_affected(avuln: Vulnerability) -> Affected | None:
     products = []
     adetail: VulnerabilityDetail
@@ -176,7 +192,15 @@ def to_cve_affected(avuln: Vulnerability) -> Affected | None:
                 # Similar to purl namespace
                 product = parts.group("package").removesuffix("\\").removesuffix("!")
                 # Similar to purl name
-                package_name = parts.group("package")
+                package_name = product
+                target_sw = parts.group("target_sw")
+                # NVD can represent the same target_sw with many different names
+                # Eg: npm, node.js, nodejs
+                if target_sw and len(target_sw) > 2:
+                    for k, v in PKG_TYPES_MAP.items():
+                        if target_sw.lower() == k or target_sw.lower() in v:
+                            target_sw = k
+                            break
                 if "/" in product:
                     tmp_a = product.split("/")
                     # ubuntu/upstream/virtualbox should become
@@ -232,14 +256,29 @@ def to_cve_affected(avuln: Vulnerability) -> Affected | None:
                         if vendor.lower() in v:
                             vendor = k
                             break
+                # We don't have a vendor, but valid target_sw
+                if not product and target_sw and len(target_sw) > 2:
+                    product = target_sw
                 p = Product(
-                    vendor=vendor,
-                    product=product,
-                    packageName=package_name,
+                    vendor=clean_vendor_product(vendor),
+                    product=clean_vendor_product(product),
+                    packageName=clean_vendor_product(package_name),
                     cpes=[Cpe(cpe_uri)],
                     defaultStatus=Status.unknown,
                     versions=versions,
                 )
+                # Support for tracking Vulnerability.affects
+                if avuln.affects:
+                    if avuln.affects.get("affected_functions"):
+                        p.programRoutines = [
+                            ProgramRoutine(name=f)
+                            for f in avuln.affects.get("affected_functions")
+                            if f
+                        ]
+                    if avuln.affects.get("affected_modules"):
+                        p.modules = [
+                            Module(m) for m in avuln.affects.get("affected_modules") if m
+                        ]
                 products.append(p)
     return Affected(products) if products else None
 
@@ -259,13 +298,78 @@ def severity_to_impact(severity: str) -> CiaType:
     return CiaType.LOW
 
 
+def severity_to_impact4(severity: str) -> str:
+    """Method to convert severity string to a valid impact enum string"""
+    if not severity:
+        return "NONE"
+    if severity.lower() in ("critical", "high", "medium", "moderate"):
+        return "HIGH"
+    return "LOW"
+
+
+def fix_maturity(maturity: str) -> str:
+    if not maturity:
+        return "NOT_DEFINED"
+    if maturity == "POC":
+        return "PROOF_OF_CONCEPT"
+    return maturity.upper()
+
+
+def fix_attack_vector(attack_vector: str) -> str:
+    if attack_vector == "ADJACENT_NETWORK":
+        return "NETWORK"
+    return attack_vector.upper()
+
+
 def to_metrics(avuln: Vulnerability) -> Metrics:
     metrics_list = []
+    if avuln.cvss4_vector_string:
+        cvss4_obj = get_cvss4_from_vector(avuln.cvss4_vector_string)
+        metrics_list.append(Metrics1(
+            cvssV4_0=Field0Model6(
+                version="4.0",
+                vectorString=avuln.cvss4_vector_string,
+                baseScore=cvss4_obj.get("baseScore"),
+                baseSeverity=config.THREAT_TO_SEVERITY.get(cvss4_obj.get("baseSeverity").lower()) if cvss4_obj.get("baseSeverity") else "LOW",
+                attackVector=fix_attack_vector(cvss4_obj.get("attackVector")),
+                attackComplexity=to_complexity_type(cvss4_obj.get("attackComplexity")),
+                attackRequirements=cvss4_obj.get("attackRequirements"),
+                privilegesRequired=cvss4_obj.get("privilegesRequired"),
+                userInteraction=cvss4_obj.get("userInteraction"),
+                vulnConfidentialityImpact=severity_to_impact4(cvss4_obj.get("vulnConfidentialityImpact")),
+                vulnIntegrityImpact=severity_to_impact4(cvss4_obj.get("vulnIntegrityImpact")),
+                vulnAvailabilityImpact=severity_to_impact4(cvss4_obj.get("vulnAvailabilityImpact")),
+                subConfidentialityImpact=severity_to_impact4(cvss4_obj.get("subConfidentialityImpact")),
+                subIntegrityImpact=severity_to_impact4(cvss4_obj.get("subIntegrityImpact")),
+                subAvailabilityImpact=severity_to_impact4(cvss4_obj.get("subAvailabilityImpact")),
+                exploitMaturity=fix_maturity(cvss4_obj.get("exploitMaturity")),
+                confidentialityRequirement=cvss4_obj.get("confidentialityRequirement"),
+                integrityRequirement=cvss4_obj.get("integrityRequirement"),
+                availabilityRequirement=cvss4_obj.get("availabilityRequirement"),
+                modifiedAttackVector=fix_attack_vector(cvss4_obj.get("modifiedAttackVector")),
+                modifiedAttackComplexity=cvss4_obj.get("modifiedAttackComplexity"),
+                modifiedAttackRequirements=cvss4_obj.get("modifiedAttackRequirements"),
+                modifiedPrivilegesRequired=cvss4_obj.get("modifiedPrivilegesRequired"),
+                modifiedUserInteraction=cvss4_obj.get("modifiedUserInteraction"),
+                modifiedVulnConfidentialityImpact=severity_to_impact4(cvss4_obj.get("modifiedVulnConfidentialityImpact")),
+                modifiedVulnIntegrityImpact=severity_to_impact4(cvss4_obj.get("modifiedVulnIntegrityImpact")),
+                modifiedVulnAvailabilityImpact=severity_to_impact4(cvss4_obj.get("modifiedVulnAvailabilityImpact")),
+                modifiedSubConfidentialityImpact=severity_to_impact4(cvss4_obj.get("modifiedSubConfidentialityImpact")),
+                modifiedSubIntegrityImpact=severity_to_impact4(cvss4_obj.get("modifiedSubIntegrityImpact")),
+                modifiedSubAvailabilityImpact=severity_to_impact4(cvss4_obj.get("modifiedSubAvailabilityImpact")),
+                Safety=cvss4_obj.get("safety"),
+                Automatable=cvss4_obj.get("automatable"),
+                Recovery=cvss4_obj.get("recovery"),
+                valueDensity=cvss4_obj.get("valueDensity"),
+                vulnerabilityResponseEffort=cvss4_obj.get("vulnerabilityResponseEffort"),
+                providerUrgency=cvss4_obj.get("providerUrgency"),
+            )
+        ))
     if avuln.cvss_v3.vector_string and avuln.cvss_v3.vector_string.startswith(
         "CVSS:3.1"
     ):
         metrics_list.append(
-            Metrics1(
+            Metrics2(
                 cvssV3_1=Field1(
                     version="3.1",
                     baseScore=avuln.cvss_v3.base_score,
@@ -288,11 +392,11 @@ def to_metrics(avuln: Vulnerability) -> Metrics:
                 )
             )
         )
-    elif avuln.cvss_v3.vector_string and avuln.cvss_v3.vector_string.startswith(
+    if avuln.cvss_v3.vector_string and avuln.cvss_v3.vector_string.startswith(
         "CVSS:3.0"
     ):
         metrics_list.append(
-            Metrics2(
+            Metrics3(
                 cvssV3_0=Field0(
                     version="3.0",
                     baseScore=avuln.cvss_v3.base_score,
@@ -389,7 +493,7 @@ def to_cve_containers(avuln: Vulnerability) -> CnaPublishedContainer | None:
 
 class CVESource(VulnerabilitySource):
     """
-    Generic CVE source that uses the CVE 5.0 models
+    Generic CVE source that uses the CVE 5.1 models
     """
 
     db_conn = None
@@ -426,7 +530,7 @@ class CVESource(VulnerabilitySource):
             if containers:
                 cve_obj = CVE1(
                     dataType=DataType.CVE_RECORD,
-                    dataVersion=DataVersion.field_5_0,
+                    dataVersion=DataVersion.field_5_1,
                     cveMetadata=to_cve_metadata(avuln),
                     containers=containers,
                 )
@@ -465,8 +569,8 @@ class CVESource(VulnerabilitySource):
                             )
                             purl_prefix = f"""pkg:{purl_type}/"""
                             if affected.product:
-                                purl_prefix = f"{purl_prefix}{affected.product}/"
-                            purl_prefix = f"{purl_prefix}{affected.packageName}"
+                                purl_prefix = f'{purl_prefix}{affected.product.replace("@", "%40").removesuffix("_")}/'
+                            purl_prefix = f'{purl_prefix}{affected.packageName.removeprefix("_")}'
                             pkg_key = f"{cve_id}|{affected.vendor}|{affected.product}|{affected.packageName}|{source_hash}"
                             index_pkg_key = f"{cve_id}|{affected.vendor}|{affected.product}|{affected.packageName}|{vers}"
                             # Filter obvious duplicates
