@@ -3,11 +3,11 @@
 from __future__ import annotations
 
 from enum import Enum
-from typing import Annotated, Any, Dict, List, Optional, Type, Union
+from typing import Annotated, Any, Dict, List, Optional, Union
 
 from pydantic import AnyUrl, AwareDatetime, BaseModel, ConfigDict, Field, NaiveDatetime, RootModel
 
-from vdb.lib.cve_model import cvss_v2, cvss_v3
+from vdb.lib.cve_model import cvss_v2, cvss_v3, cvss_v4
 
 
 class UriType(RootModel[AnyUrl]):
@@ -51,6 +51,19 @@ class ReferenceTags(Enum):
     vdb_entry = "vdb-entry"
 
 
+class Type(Enum):
+    finder = "finder"
+    reporter = "reporter"
+    analyst = "analyst"
+    coordinator = "coordinator"
+    remediation_developer = "remediation developer"
+    remediation_reviewer = "remediation reviewer"
+    remediation_verifier = "remediation verifier"
+    tool = "tool"
+    sponsor = "sponsor"
+    other = "other"
+
+
 # Removed patten validation to support a wide range of CVE id
 class CveId(RootModel[str]):
     root: Annotated[str, Field(min_length=4, max_length=128)]
@@ -195,7 +208,49 @@ class Versions(BaseModel):
     versionType: Annotated[
         Optional[str],
         Field(
-            None,
+            description="The version numbering system used for specifying the range. This defines the exact semantics of the comparison (less-than) operation on versions, which is required to understand the range itself. 'Custom' indicates that the version type is unspecified and should be avoided whenever possible. It is included primarily for use in conversion of older data files.",
+            examples=["custom", "git", "maven", "python", "rpm", "semver"],
+            max_length=128,
+            min_length=1,
+        ),
+    ] = None
+    lessThan: Annotated[
+        Optional[Version],
+        Field(
+            description="The non-inclusive upper limit of the range. This is the least version NOT in the range. The usual version syntax is expanded to allow a pattern to end in an asterisk `(*)`, indicating an arbitrarily large number in the version ordering. For example, `{version: 1.0 lessThan: 1.*}` would describe the entire 1.X branch for most range kinds, and `{version: 2.0, lessThan: *}` describes all versions starting at 2.0, including 3.0, 5.1, and so on. Only one of lessThan and lessThanOrEqual should be specified."
+        ),
+    ] = None
+    lessThanOrEqual: Annotated[
+        Optional[Version],
+        Field(
+            description="The inclusive upper limit of the range. This is the greatest version contained in the range. Only one of lessThan and lessThanOrEqual should be specified. For example, `{version: 1.0, lessThanOrEqual: 1.3}` covers all versions from 1.0 up to and including 1.3."
+        ),
+    ] = None
+    changes: Annotated[
+        Optional[List[Change]],
+        Field(
+            description="A list of status changes that take place during the range. The array should be sorted in increasing order by the 'at' field, according to the versionType, but clients must re-sort the list themselves rather than assume it is sorted.",
+            min_length=1,
+        ),
+    ] = None
+
+
+class Versions1(BaseModel):
+    version: Annotated[
+        Version,
+        Field(
+            description="The single version being described, or the version at the start of the range. By convention, typically 0 denotes the earliest possible version."
+        ),
+    ]
+    status: Annotated[
+        Status,
+        Field(
+            description="The vulnerability status for the version or range of versions. For a range, the status may be refined by the 'changes' list."
+        ),
+    ]
+    versionType: Annotated[
+        str,
+        Field(
             description="The version numbering system used for specifying the range. This defines the exact semantics of the comparison (less-than) operation on versions, which is required to understand the range itself. 'Custom' indicates that the version type is unspecified and should be avoided whenever possible. It is included primarily for use in conversion of older data files.",
             examples=["custom", "git", "maven", "python", "rpm", "semver"],
             max_length=128,
@@ -205,28 +260,25 @@ class Versions(BaseModel):
     lessThan: Annotated[
         Optional[Version],
         Field(
-            None,
-            description="The non-inclusive upper limit of the range. This is the least version NOT in the range. The usual version syntax is expanded to allow a pattern to end in an asterisk `(*)`, indicating an arbitrarily large number in the version ordering. For example, `{version: 1.0 lessThan: 1.*}` would describe the entire 1.X branch for most range kinds, and `{version: 2.0, lessThan: *}` describes all versions starting at 2.0, including 3.0, 5.1, and so on. Only one of lessThan and lessThanOrEqual should be specified.",
+            description="The non-inclusive upper limit of the range. This is the least version NOT in the range. The usual version syntax is expanded to allow a pattern to end in an asterisk `(*)`, indicating an arbitrarily large number in the version ordering. For example, `{version: 1.0 lessThan: 1.*}` would describe the entire 1.X branch for most range kinds, and `{version: 2.0, lessThan: *}` describes all versions starting at 2.0, including 3.0, 5.1, and so on. Only one of lessThan and lessThanOrEqual should be specified."
         ),
-    ]
+    ] = None
     lessThanOrEqual: Annotated[
         Optional[Version],
         Field(
-            None,
-            description="The inclusive upper limit of the range. This is the greatest version contained in the range. Only one of lessThan and lessThanOrEqual should be specified. For example, `{version: 1.0, lessThanOrEqual: 1.3}` covers all versions from 1.0 up to and including 1.3.",
+            description="The inclusive upper limit of the range. This is the greatest version contained in the range. Only one of lessThan and lessThanOrEqual should be specified. For example, `{version: 1.0, lessThanOrEqual: 1.3}` covers all versions from 1.0 up to and including 1.3."
         ),
-    ]
+    ] = None
     changes: Annotated[
         Optional[List[Change]],
         Field(
-            None,
             description="A list of status changes that take place during the range. The array should be sorted in increasing order by the 'at' field, according to the versionType, but clients must re-sort the list themselves rather than assume it is sorted.",
             min_length=1,
         ),
-    ]
+    ] = None
 
 
-class Versions1(BaseModel):
+class Versions2(BaseModel):
     version: Annotated[
         Version,
         Field(
@@ -257,21 +309,19 @@ class Versions1(BaseModel):
     lessThanOrEqual: Annotated[
         Optional[Version],
         Field(
-            None,
-            description="The inclusive upper limit of the range. This is the greatest version contained in the range. Only one of lessThan and lessThanOrEqual should be specified. For example, `{version: 1.0, lessThanOrEqual: 1.3}` covers all versions from 1.0 up to and including 1.3.",
+            description="The inclusive upper limit of the range. This is the greatest version contained in the range. Only one of lessThan and lessThanOrEqual should be specified. For example, `{version: 1.0, lessThanOrEqual: 1.3}` covers all versions from 1.0 up to and including 1.3."
         ),
-    ]
+    ] = None
     changes: Annotated[
         Optional[List[Change]],
         Field(
-            None,
             description="A list of status changes that take place during the range. The array should be sorted in increasing order by the 'at' field, according to the versionType, but clients must re-sort the list themselves rather than assume it is sorted.",
             min_length=1,
         ),
-    ]
+    ] = None
 
 
-class Versions2(BaseModel):
+class Versions3(BaseModel):
     version: Annotated[
         Version,
         Field(
@@ -296,10 +346,9 @@ class Versions2(BaseModel):
     lessThan: Annotated[
         Optional[Version],
         Field(
-            None,
-            description="The non-inclusive upper limit of the range. This is the least version NOT in the range. The usual version syntax is expanded to allow a pattern to end in an asterisk `(*)`, indicating an arbitrarily large number in the version ordering. For example, `{version: 1.0 lessThan: 1.*}` would describe the entire 1.X branch for most range kinds, and `{version: 2.0, lessThan: *}` describes all versions starting at 2.0, including 3.0, 5.1, and so on. Only one of lessThan and lessThanOrEqual should be specified.",
+            description="The non-inclusive upper limit of the range. This is the least version NOT in the range. The usual version syntax is expanded to allow a pattern to end in an asterisk `(*)`, indicating an arbitrarily large number in the version ordering. For example, `{version: 1.0 lessThan: 1.*}` would describe the entire 1.X branch for most range kinds, and `{version: 2.0, lessThan: *}` describes all versions starting at 2.0, including 3.0, 5.1, and so on. Only one of lessThan and lessThanOrEqual should be specified."
         ),
-    ]
+    ] = None
     lessThanOrEqual: Annotated[
         Version,
         Field(
@@ -309,36 +358,30 @@ class Versions2(BaseModel):
     changes: Annotated[
         Optional[List[Change]],
         Field(
-            None,
             description="A list of status changes that take place during the range. The array should be sorted in increasing order by the 'at' field, according to the versionType, but clients must re-sort the list themselves rather than assume it is sorted.",
             min_length=1,
         ),
-    ]
+    ] = None
 
 
 class Product(BaseModel):
     vendor: Annotated[
         Optional[str],
         Field(
-            None,
             description="Name of the organization, project, community, individual, or user that created or maintains this product or hosted service. Can be 'N/A' if none of those apply. When collectionURL and packageName are used, this field may optionally represent the user or account within the package collection associated with the package.",
             max_length=512,
             min_length=1,
         ),
-    ]
+    ] = None
     product: Annotated[
         Optional[str],
         Field(
-            None,
-            description="Name of the affected product.",
-            max_length=2048,
-            min_length=1,
+            description="Name of the affected product.", max_length=2048, min_length=1
         ),
-    ]
+    ] = None
     collectionURL: Annotated[
         Optional[UriType],
         Field(
-            None,
             description="URL identifying a package collection (determines the meaning of packageName).",
             examples=[
                 "https://access.redhat.com/downloads/content/package-browser",
@@ -406,72 +449,64 @@ class Product(BaseModel):
                 "https://wordpress.org/plugins",
             ],
         ),
-    ]
+    ] = None
     packageName: Annotated[
         Optional[str],
         Field(
-            None,
             description="Name or identifier of the affected software package as used in the package collection.",
             max_length=2048,
             min_length=1,
         ),
-    ]
+    ] = None
     cpes: Annotated[
         Optional[List[Cpe]],
         Field(
-            None,
-            description='Affected products defined by CPE. This is an array of CPE values (vulnerable and not), we use an array so that we can make multiple statements about the same version and they are separate (if we used a JSON object we\'d essentially be keying on the CPE name and they would have to overlap). Also, this allows things like cveDataVersion or cveDescription to be applied directly to the product entry. This also allows more complex statements such as "Product X between versions 10.2 and 10.8" to be put in a machine-readable format. As well since multiple statements can be used multiple branches of the same product can be defined here.',
+            description='Affected products defined by CPE. This is an array of CPE values (vulnerable and not), we use an array so that we can make multiple statements about the same version and they are separate (if we used a JSON object we\'d essentially be keying on the CPE name and they would have to overlap). Also, this allows things like cveDataVersion or cveDescription to be applied directly to the product entry. This also allows more complex statements such as "Product X between versions 10.2 and 10.8" to be put in a machine-readable format. As well since multiple statements can be used multiple branches of the same product can be defined here.'
         ),
-    ]
+    ] = None
     modules: Annotated[
         Optional[List[Module]],
         Field(
-            None,
-            description="A list of the affected components, features, modules, sub-components, sub-products, APIs, commands, utilities, programs, or functionalities (optional).",
+            description="A list of the affected components, features, modules, sub-components, sub-products, APIs, commands, utilities, programs, or functionalities (optional)."
         ),
-    ]
+    ] = None
     programFiles: Annotated[
         Optional[List[ProgramFile]],
-        Field(None, description="A list of the affected source code files (optional)."),
-    ]
+        Field(description="A list of the affected source code files (optional)."),
+    ] = None
     programRoutines: Annotated[
         Optional[List[ProgramRoutine]],
         Field(
-            None,
-            description="A list of the affected source code functions, methods, subroutines, or procedures (optional).",
+            description="A list of the affected source code functions, methods, subroutines, or procedures (optional)."
         ),
-    ]
+    ] = None
     platforms: Annotated[
         Optional[List[Platform]],
         Field(
-            None,
             description="List of specific platforms if the vulnerability is only relevant in the context of these platforms (optional). Platforms may include execution environments, operating systems, virtualization technologies, hardware models, or computing architectures. The lack of this field or an empty array implies that the other fields are applicable to all relevant platforms.",
             min_length=1,
             title="Platforms",
         ),
-    ]
+    ] = None
     repo: Annotated[
         Optional[UriType],
         Field(
-            None,
-            description="The URL of the source code repository, for informational purposes and/or to resolve git hash version ranges.",
+            description="The URL of the source code repository, for informational purposes and/or to resolve git hash version ranges."
         ),
-    ]
+    ] = None
     defaultStatus: Annotated[
         Optional[Status],
         Field(
-            None,
-            description="The default status for versions that are not otherwise listed in the versions list. If not specified, defaultStatus defaults to 'unknown'. Versions or defaultStatus may be omitted, but not both.",
+            description="The default status for versions that are not otherwise listed in the versions list. If not specified, defaultStatus defaults to 'unknown'. Versions or defaultStatus may be omitted, but not both."
         ),
-    ]
+    ] = None
     versions: Annotated[
-        Optional[List[Union[Versions, Union[Versions1, Versions2]]]],
+        Optional[List[Union[Versions, Versions1, Versions2, Versions3]]],
         Field(
-            None,
             description="Set of product versions or version ranges related to the vulnerability. The versions satisfy the CNA Rules [8.1.2 requirement](https://cve.mitre.org/cve/cna/rules.html#section_8-1_cve_entry_information_requirements). Versions or defaultStatus may be omitted, but not both.",
             min_length=1,
         ),
-    ]
+    ] = None
 
 
 class DataType(Enum):
@@ -480,6 +515,7 @@ class DataType(Enum):
 
 class DataVersion(Enum):
     field_5_0 = "5.0"
+    field_5_1 = "5.1"
 
 
 class State(Enum):
@@ -502,40 +538,36 @@ class CveMetadataPublished(BaseModel):
     assignerShortName: Annotated[
         Optional[ShortName],
         Field(
-            None,
-            description="The short name for the organization to which the CVE ID was originally assigned.",
+            description="The short name for the organization to which the CVE ID was originally assigned."
         ),
-    ]
+    ] = None
     requesterUserId: Annotated[
         Optional[UserId],
-        Field(None, description="The user that requested the CVE identifier."),
-    ]
+        Field(description="The user that requested the CVE identifier."),
+    ] = None
     dateUpdated: Annotated[
         Optional[AwareDatetime | NaiveDatetime],
-        Field(None, description="The date/time the record was last updated."),
-    ]
+        Field(description="The date/time the record was last updated."),
+    ] = None
     serial: Annotated[
         Optional[int],
         Field(
-            None,
             description="The system of record causes this to start at 1, and increment by 1 each time a submission from a data provider changes this CVE Record. The incremented value moves to the Rejected schema upon a PUBLISHED->REJECTED transition, and moves to the Published schema upon a REJECTED->PUBLISHED transition.",
             ge=1,
         ),
-    ]
+    ] = None
     dateReserved: Annotated[
         Optional[AwareDatetime | NaiveDatetime],
         Field(
-            None,
-            description="The date/time this CVE ID was reserved in the CVE automation workgroup services system. Disclaimer: This date reflects when the CVE ID was reserved, and does not necessarily indicate when this vulnerability was discovered, shared with the affected vendor, publicly disclosed, or updated in CVE.",
+            description="The date/time this CVE ID was reserved in the CVE automation workgroup services system. Disclaimer: This date reflects when the CVE ID was reserved, and does not necessarily indicate when this vulnerability was discovered, shared with the affected vendor, publicly disclosed, or updated in CVE."
         ),
-    ]
+    ] = None
     datePublished: Annotated[
         Optional[AwareDatetime | NaiveDatetime],
         Field(
-            None,
-            description="The date/time the CVE Record was first published in the CVE List.",
+            description="The date/time the CVE Record was first published in the CVE List."
         ),
-    ]
+    ] = None
     state: Annotated[State, Field(description="State of CVE - PUBLISHED, REJECTED.")]
 
 
@@ -559,41 +591,36 @@ class CveMetadataRejected(BaseModel):
     assignerShortName: Annotated[
         Optional[ShortName],
         Field(
-            None,
-            description="The short name for the organization to which the CVE ID was originally assigned.",
+            description="The short name for the organization to which the CVE ID was originally assigned."
         ),
-    ]
+    ] = None
     serial: Annotated[
         Optional[int],
         Field(
-            None,
             description="The system of record causes this to start at 1, and increment by 1 each time a submission from a data provider changes this CVE Record. The incremented value moves to the Rejected schema upon a PUBLISHED->REJECTED transition, and moves to the Published schema upon a REJECTED->PUBLISHED transition.",
             ge=1,
         ),
-    ]
+    ] = None
     dateUpdated: Annotated[
         Optional[AwareDatetime | NaiveDatetime],
-        Field(None, description="The date/time the record was last updated."),
-    ]
+        Field(description="The date/time the record was last updated."),
+    ] = None
     datePublished: Annotated[
         Optional[AwareDatetime | NaiveDatetime],
         Field(
-            None,
-            description="The date/time the CVE Record was first published in the CVE List.",
+            description="The date/time the CVE Record was first published in the CVE List."
         ),
-    ]
+    ] = None
     dateRejected: Annotated[
-        Optional[AwareDatetime | NaiveDatetime],
-        Field(None, description="The date/time the CVE ID was rejected."),
-    ]
+        Optional[AwareDatetime | NaiveDatetime], Field(description="The date/time the CVE ID was rejected.")
+    ] = None
     state: Annotated[State1, Field(description="State of CVE - PUBLISHED, REJECTED.")]
     dateReserved: Annotated[
         Optional[AwareDatetime | NaiveDatetime],
         Field(
-            None,
-            description="The date/time this CVE ID was reserved in the CVE automation workgroup services system. Disclaimer: This date reflects when the CVE ID was reserved, and does not necessarily indicate when this vulnerability was discovered, shared with the affected vendor, publicly disclosed, or updated in CVE.",
+            description="The date/time this CVE ID was reserved in the CVE automation workgroup services system. Disclaimer: This date reflects when the CVE ID was reserved, and does not necessarily indicate when this vulnerability was discovered, shared with the affected vendor, publicly disclosed, or updated in CVE."
         ),
-    ]
+    ] = None
 
 
 class ProviderMetadata(BaseModel):
@@ -602,15 +629,14 @@ class ProviderMetadata(BaseModel):
     ]
     shortName: Annotated[
         Optional[ShortName],
-        Field(None, description="The container provider's organizational short name."),
-    ]
+        Field(description="The container provider's organizational short name."),
+    ] = None
     dateUpdated: Annotated[
         Optional[AwareDatetime | NaiveDatetime],
         Field(
-            None,
-            description="Timestamp to be set by the system of record at time of submission. If dateUpdated is provided to the system of record it will be replaced by the current timestamp at the time of submission.",
+            description="Timestamp to be set by the system of record at time of submission. If dateUpdated is provided to the system of record it will be replaced by the current timestamp at the time of submission."
         ),
-    ]
+    ] = None
 
 
 class Affected(RootModel[List[Product]]):
@@ -639,11 +665,10 @@ class SupportingMediaItem(BaseModel):
     base64: Annotated[
         Optional[bool],
         Field(
-            False,
             description="If true then the value field contains the media data encoded in base64. If false then the value field contains the UTF-8 media content.",
             title="Encoding",
         ),
-    ]
+    ] = False
     # Removed max_length
     value: Annotated[
         str,
@@ -723,19 +748,26 @@ class TaxonomyRelation(BaseModel):
 class TaxonomyMapping(BaseModel):
     taxonomyName: Annotated[
         str,
-        Field(description="The name of the taxonomy.", max_length=128, min_length=1),
-    ]
-    taxonomyVersion: Annotated[
-        Optional[str],
         Field(
-            None,
-            description="The version of taxonomy the identifiers come from.",
+            description="The name of the taxonomy, eg., ATT&CK, D3FEND, CWE, CVSS",
             max_length=128,
             min_length=1,
         ),
     ]
+    taxonomyVersion: Annotated[
+        Optional[str],
+        Field(
+            description="The version of taxonomy the identifiers come from.",
+            max_length=128,
+            min_length=1,
+        ),
+    ] = None
     taxonomyRelations: Annotated[
-        List[TaxonomyRelation], Field(description="", min_length=1)
+        List[TaxonomyRelation],
+        Field(
+            description="List of relationships to the taxonomy for the vulnerability.",
+            min_length=1,
+        ),
     ]
 
 
@@ -773,20 +805,18 @@ class Reference(BaseModel):
     name: Annotated[
         Optional[str],
         Field(
-            None,
             description="User created name for the reference, often the title of the page.",
             max_length=512,
             min_length=1,
         ),
-    ]
+    ] = None
     tags: Annotated[
         Optional[List[Union[TagExtension, ReferenceTags]]],
         Field(
-            None,
             description="An array of one or more tags that describe the resource referenced by 'url'.",
             min_length=1,
         ),
-    ]
+    ] = None
 
 
 class Description(BaseModel):
@@ -795,17 +825,16 @@ class Description(BaseModel):
     )
     lang: Language
     value: Annotated[
-        str, Field(description="Plain text description.", min_length=1, max_length=4096)
+        str, Field(description="Plain text description.", max_length=4096, min_length=1)
     ]
     supportingMedia: Annotated[
         Optional[List[SupportingMediaItem]],
         Field(
-            None,
             description="Supporting media data for the description such as markdown, diagrams, .. (optional). Similar to RFC 2397 each media object has three main parts: media type, media data value, and an optional boolean flag to indicate if the media data is base64 encoded.",
             min_length=1,
             title="Supporting media",
         ),
-    ]
+    ] = None
 
 
 class EnglishLanguageDescription(BaseModel):
@@ -837,13 +866,12 @@ class Impact(BaseModel):
     capecId: Annotated[
         Optional[str],
         Field(
-            None,
             description="CAPEC ID that best relates to this impact.",
             max_length=11,
             min_length=7,
             pattern="^CAPEC-[1-9][0-9]{0,4}$",
         ),
-    ]
+    ] = None
     descriptions: Annotated[
         Descriptions,
         Field(
@@ -913,7 +941,7 @@ class TimelineItem(BaseModel):
     time: Annotated[
         AwareDatetime,
         Field(
-            description="Timestamp representing when the event in the timeline occurred. The timestamp format is based on RFC3339 and ISO ISO8601, with an optional timezone. yyyy-MM-ddTHH:mm:ssZZZZ - if the timezone offset is not given, GMT (0000) is assumed."
+            description="Timestamp representing when the event in the timeline occurred. The timestamp format is based on RFC3339 and ISO ISO8601, with an optional timezone. yyyy-MM-ddTHH:mm:ss[+-]ZH:ZM - if the timezone offset is not given, GMT (+00:00) is assumed."
         ),
     ]
     lang: Annotated[
@@ -948,17 +976,15 @@ class Credit(BaseModel):
     user: Annotated[
         Optional[UuidType],
         Field(
-            None,
-            description="UUID of the user being credited if present in the CVE User Registry (optional). This UUID can be used to lookup the user record in the user registry service.",
+            description="UUID of the user being credited if present in the CVE User Registry (optional). This UUID can be used to lookup the user record in the user registry service."
         ),
-    ]
+    ] = None
     type: Annotated[
         Optional[Type],
         Field(
-            "finder",
-            description="Type or role of the entity being credited (optional). finder: identifies the vulnerability.\nreporter: notifies the vendor of the vulnerability to a CNA.\nanalyst: validates the vulnerability to ensure accuracy or severity.\ncoordinator: facilitates the coordinated response process.\nremediation developer: prepares a code change or other remediation plans.\nremediation reviewer: reviews vulnerability remediation plans or code changes for effectiveness and completeness.\nremediation verifier: tests and verifies the vulnerability or its remediation.\ntool: names of tools used in vulnerability discovery or identification.\nsponsor: supports the vulnerability identification or remediation activities.",
+            description="Type or role of the entity being credited (optional). finder: identifies the vulnerability.\nreporter: notifies the vendor of the vulnerability to a CNA.\nanalyst: validates the vulnerability to ensure accuracy or severity.\ncoordinator: facilitates the coordinated response process.\nremediation developer: prepares a code change or other remediation plans.\nremediation reviewer: reviews vulnerability remediation plans or code changes for effectiveness and completeness.\nremediation verifier: tests and verifies the vulnerability or its remediation.\ntool: names of tools used in vulnerability discovery or identification.\nsponsor: supports the vulnerability identification or remediation activities."
         ),
-    ]
+    ] = "finder"
 
 
 class Credits(RootModel[List[Credit]]):
@@ -1002,11 +1028,10 @@ class CnaRejectedContainer(BaseModel):
     replacedBy: Annotated[
         Optional[List[CveId]],
         Field(
-            None,
             description="Contains an array of CVE IDs that this CVE ID was rejected in favor of because this CVE ID was assigned to the vulnerabilities.",
             min_length=1,
         ),
-    ]
+    ] = None
 
 
 class Description1(BaseModel):
@@ -1021,22 +1046,20 @@ class Description1(BaseModel):
     cweId: Annotated[
         Optional[str],
         Field(
-            None,
             description="CWE ID of the CWE that best describes this problemType entry.",
             max_length=9,
             min_length=5,
             pattern="^CWE-[1-9][0-9]*$",
         ),
-    ]
+    ] = None
     type: Annotated[
         Optional[str],
         Field(
-            None,
             description="Problemtype source, text, OWASP, CWE, etc.,",
             max_length=128,
             min_length=1,
         ),
-    ]
+    ] = None
     references: Optional[References] = None
 
 
@@ -1058,110 +1081,131 @@ class Metrics1(BaseModel):
     format: Annotated[
         Optional[str],
         Field(
-            None,
             description="Name of the scoring format. This provides a bit of future proofing. Additional properties are not prohibited, so this will support the inclusion of proprietary formats. It also provides an easy future conversion mechanism when future score formats become part of the schema. example: cvssV44, format = 'cvssV44', other = cvssV4_4 JSON object. In the future, the other properties can be converted to score properties when they become part of the schema.",
             max_length=64,
             min_length=1,
         ),
-    ]
+    ] = None
     scenarios: Annotated[
         Optional[List[Scenario]],
         Field(
-            None,
             description="Description of the scenarios this metrics object applies to. If no specific scenario is given, GENERAL is used as the default and applies when no more specific metric matches.",
             min_length=1,
         ),
-    ]
-    cvssV3_1: cvss_v3.Field1
+    ] = None
+    cvssV4_0: cvss_v4.Field0Model6
+    cvssV3_1: Optional[cvss_v3.Field1] = None
     cvssV3_0: Optional[cvss_v3.Field0] = None
     cvssV2_0: Optional[cvss_v2.Field0] = None
     other: Annotated[
         Optional[Other],
         Field(
-            None,
-            description="A non-standard impact description, may be prose or JSON block.",
+            description="A non-standard impact description, may be prose or JSON block."
         ),
-    ]
+    ] = None
 
 
 class Metrics2(BaseModel):
     format: Annotated[
         Optional[str],
         Field(
-            None,
             description="Name of the scoring format. This provides a bit of future proofing. Additional properties are not prohibited, so this will support the inclusion of proprietary formats. It also provides an easy future conversion mechanism when future score formats become part of the schema. example: cvssV44, format = 'cvssV44', other = cvssV4_4 JSON object. In the future, the other properties can be converted to score properties when they become part of the schema.",
             max_length=64,
             min_length=1,
         ),
-    ]
+    ] = None
     scenarios: Annotated[
         Optional[List[Scenario]],
         Field(
-            None,
             description="Description of the scenarios this metrics object applies to. If no specific scenario is given, GENERAL is used as the default and applies when no more specific metric matches.",
             min_length=1,
         ),
-    ]
-    cvssV3_1: Optional[cvss_v3.Field1] = None
-    cvssV3_0: cvss_v3.Field0
+    ] = None
+    cvssV4_0: Optional[cvss_v4.Field0Model6] = None
+    cvssV3_1: cvss_v3.Field1
+    cvssV3_0: Optional[cvss_v3.Field0] = None
     cvssV2_0: Optional[cvss_v2.Field0] = None
     other: Annotated[
         Optional[Other],
         Field(
-            None,
-            description="A non-standard impact description, may be prose or JSON block.",
+            description="A non-standard impact description, may be prose or JSON block."
         ),
-    ]
+    ] = None
 
 
 class Metrics3(BaseModel):
     format: Annotated[
         Optional[str],
         Field(
-            None,
             description="Name of the scoring format. This provides a bit of future proofing. Additional properties are not prohibited, so this will support the inclusion of proprietary formats. It also provides an easy future conversion mechanism when future score formats become part of the schema. example: cvssV44, format = 'cvssV44', other = cvssV4_4 JSON object. In the future, the other properties can be converted to score properties when they become part of the schema.",
             max_length=64,
             min_length=1,
         ),
-    ]
+    ] = None
     scenarios: Annotated[
         Optional[List[Scenario]],
         Field(
-            None,
             description="Description of the scenarios this metrics object applies to. If no specific scenario is given, GENERAL is used as the default and applies when no more specific metric matches.",
             min_length=1,
         ),
-    ]
+    ] = None
+    cvssV4_0: Optional[cvss_v4.Field0Model6] = None
     cvssV3_1: Optional[cvss_v3.Field1] = None
-    cvssV3_0: Optional[cvss_v3.Field0] = None
-    cvssV2_0: cvss_v2.Field0
+    cvssV3_0: cvss_v3.Field0
+    cvssV2_0: Optional[cvss_v2.Field0] = None
     other: Annotated[
         Optional[Other],
         Field(
-            None,
-            description="A non-standard impact description, may be prose or JSON block.",
+            description="A non-standard impact description, may be prose or JSON block."
         ),
-    ]
+    ] = None
 
 
 class Metrics4(BaseModel):
     format: Annotated[
         Optional[str],
         Field(
-            None,
             description="Name of the scoring format. This provides a bit of future proofing. Additional properties are not prohibited, so this will support the inclusion of proprietary formats. It also provides an easy future conversion mechanism when future score formats become part of the schema. example: cvssV44, format = 'cvssV44', other = cvssV4_4 JSON object. In the future, the other properties can be converted to score properties when they become part of the schema.",
             max_length=64,
             min_length=1,
         ),
-    ]
+    ] = None
     scenarios: Annotated[
         Optional[List[Scenario]],
         Field(
-            None,
             description="Description of the scenarios this metrics object applies to. If no specific scenario is given, GENERAL is used as the default and applies when no more specific metric matches.",
             min_length=1,
         ),
-    ]
+    ] = None
+    cvssV4_0: Optional[cvss_v4.Field0Model6] = None
+    cvssV3_1: Optional[cvss_v3.Field1] = None
+    cvssV3_0: Optional[cvss_v3.Field0] = None
+    cvssV2_0: cvss_v2.Field0
+    other: Annotated[
+        Optional[Other],
+        Field(
+            description="A non-standard impact description, may be prose or JSON block."
+        ),
+    ] = None
+
+
+class Metrics5(BaseModel):
+    format: Annotated[
+        Optional[str],
+        Field(
+            description="Name of the scoring format. This provides a bit of future proofing. Additional properties are not prohibited, so this will support the inclusion of proprietary formats. It also provides an easy future conversion mechanism when future score formats become part of the schema. example: cvssV44, format = 'cvssV44', other = cvssV4_4 JSON object. In the future, the other properties can be converted to score properties when they become part of the schema.",
+            max_length=64,
+            min_length=1,
+        ),
+    ] = None
+    scenarios: Annotated[
+        Optional[List[Scenario]],
+        Field(
+            description="Description of the scenarios this metrics object applies to. If no specific scenario is given, GENERAL is used as the default and applies when no more specific metric matches.",
+            min_length=1,
+        ),
+    ] = None
+    cvssV4_0: Optional[cvss_v4.Field0Model6] = None
     cvssV3_1: Optional[cvss_v3.Field1] = None
     cvssV3_0: Optional[cvss_v3.Field0] = None
     cvssV2_0: Optional[cvss_v2.Field0] = None
@@ -1173,9 +1217,9 @@ class Metrics4(BaseModel):
     ]
 
 
-class Metrics(RootModel[List[Union[Metrics1, Metrics2, Metrics3, Metrics4]]]):
+class Metrics(RootModel[List[Union[Metrics1, Metrics2, Metrics3, Metrics4, Metrics5]]]):
     root: Annotated[
-        List[Union[Metrics1, Metrics2, Metrics3, Metrics4]],
+        List[Union[Metrics1, Metrics2, Metrics3, Metrics4, Metrics5]],
         Field(
             description="Collection of impact scores with attribution.", min_length=1
         ),
@@ -1212,26 +1256,23 @@ class CnaPublishedContainer(BaseModel):
     dateAssigned: Annotated[
         Optional[AwareDatetime | NaiveDatetime],
         Field(
-            None,
-            description="The date/time this CVE ID was associated with a vulnerability by a CNA.",
+            description="The date/time this CVE ID was associated with a vulnerability by a CNA."
         ),
-    ]
+    ] = None
     datePublic: Annotated[
         Optional[AwareDatetime | NaiveDatetime],
         Field(
-            None,
-            description="If known, the date/time the vulnerability was disclosed publicly.",
+            description="If known, the date/time the vulnerability was disclosed publicly."
         ),
-    ]
+    ] = None
     title: Annotated[
         Optional[str],
         Field(
-            None,
             description="A title, headline, or a brief phrase summarizing the CVE record. Eg., Buffer overflow in Example Soft.",
             max_length=256,
             min_length=1,
         ),
-    ]
+    ] = None
     descriptions: Descriptions
     affected: Affected
     problemTypes: Optional[ProblemTypes] = None
@@ -1260,19 +1301,17 @@ class AdpContainer(BaseModel):
     datePublic: Annotated[
         Optional[AwareDatetime | NaiveDatetime],
         Field(
-            None,
-            description="If known, the date/time the vulnerability was disclosed publicly.",
+            description="If known, the date/time the vulnerability was disclosed publicly."
         ),
-    ]
+    ] = None
     title: Annotated[
         Optional[str],
         Field(
-            None,
             description="A title, headline, or a brief phrase summarizing the information in an ADP container.",
             max_length=256,
             min_length=1,
         ),
-    ]
+    ] = None
     descriptions: Optional[Descriptions] = None
     affected: Optional[Affected] = None
     problemTypes: Optional[ProblemTypes] = None
@@ -1295,7 +1334,7 @@ class Containers(BaseModel):
         extra="forbid",
     )
     cna: Optional[CnaPublishedContainer]
-    adp: Annotated[Optional[List[AdpContainer]], Field(None, min_length=1)]
+    adp: Annotated[Optional[List[AdpContainer]], Field(min_length=1)] = None
 
 
 class CVE1(BaseModel):
