@@ -16,7 +16,7 @@ from vdb.lib import (
     config,
 )
 from vdb.lib.cve import CVESource
-from vdb.lib.utils import url_to_purl
+from vdb.lib.utils import clean_cpe_uri, extract_affected_symbols, url_to_purl
 
 
 logging.basicConfig(
@@ -107,6 +107,8 @@ def filterable_git_url(url: str, hostname: str) -> bool:
         "enterprise.github.com",
         "git-scm.com",
         "docs.",
+        "github.blog",
+        "github.dev",
     ):
         if part in hostname.lower():
             return True
@@ -302,8 +304,8 @@ class NvdSource(CVESource):
                 detail = {}
                 if not cpe.get("cpe23Uri"):
                     continue
-                if cpe["vulnerable"] and cpe.get("cpe23Uri"):
-                    detail["cpe_uri"] = cpe["cpe23Uri"]
+                if cpe["vulnerable"]:
+                    detail["cpe_uri"] = clean_cpe_uri(cpe.get("cpe23Uri"))
                     detail["mii"] = cpe.get("versionStartIncluding")
                     detail["mie"] = cpe.get("versionStartExcluding")
                     detail["mai"] = cpe.get("versionEndIncluding")
@@ -313,7 +315,7 @@ class NvdSource(CVESource):
                     cpe_details_list.append(detail)
                 else:  # cpe is not vulnerable
                     if node["operator"] == "OR":
-                        fix_cpe_uri = cpe["cpe23Uri"]
+                        fix_cpe_uri = clean_cpe_uri(cpe["cpe23Uri"])
             # Add fix version details
             for det in cpe_details_list:
                 if fix_cpe_uri:
@@ -377,7 +379,7 @@ class NvdSource(CVESource):
                 )
                 version_end_including = cpe.get("versionEndIncluding", single_version)
                 detail = {
-                    "cpe_uri": cpe_uri,
+                    "cpe_uri": clean_cpe_uri(cpe_uri),
                     "mii": version_start_including,
                     "mie": cpe.get("versionStartExcluding"),
                     "mai": version_end_including,
@@ -433,6 +435,12 @@ class NvdSource(CVESource):
                 problem_type = aweakness["description"][0]["value"]
                 break
         description = NvdSource._get_value(vuln, "descriptions")
+        # Ignore disputed CVEs. Eg: CVE-2023-35116
+        # CVE-2023-39017 uses the phrase "this is disputed"
+        for ds in ("** DISPUTED **", "this is not a valid vulnerability report", "this is disputed"):
+            if ds in description:
+                return None
+        affected_symbols = extract_affected_symbols(description)
         rdata = vuln.get("references", [])
         related_urls = [r["url"] for r in rdata]
         metrics = vuln.get("metrics", {})
@@ -441,6 +449,8 @@ class NvdSource(CVESource):
             cvss_metrics = metrics.get("cvssMetricV31")
         elif metrics.get("cvssMetricV30"):
             cvss_metrics = metrics.get("cvssMetricV30")
+        if not cvss_metrics:
+            return None
         cvss_data = cvss_metrics[0].get("cvssData")
         cvss_v3 = CvssV3(
             base_score=cvss_data["baseScore"],
@@ -473,4 +483,5 @@ class NvdSource(CVESource):
             cvss_v3,
             vuln["lastModified"],
             vuln["published"],
+            affected_symbols
         )
