@@ -3,7 +3,7 @@ osv to NVD CVE converter
 
 This module fetches the vulnerability data from osv.dev and stores them in NVD CVE 1.1 json format.
 """
-
+from os import getenv
 from zipfile import ZipFile
 
 import httpx
@@ -16,10 +16,12 @@ from vdb.lib.utils import (
     compress_str,
     convert_score_severity,
     get_cvss3_from_vector,
+    get_cvss4_from_vector,
     get_default_cve_data,
     parse_purl,
 )
 
+
 # Size of the stream to read and write to the file
 DOWNLOAD_CHUNK_SIZE = 4096
 
@@ -33,6 +35,18 @@ vendor_overrides = {
 }
 
 
+def functions_to_modules(affected_functions):
+    affected_modules = set()
+    for af in affected_functions:
+        if "::" in af:
+            tmp_parts = af.split("::")
+            affected_modules.add("::".join(tmp_parts[:-1]))
+        elif "/" in af:
+            tmp_parts = af.split("/")
+            affected_modules.add("/".join(tmp_parts[:-1]))
+    return affected_modules
+
+
 class OSVSource(NvdSource):
     """OSV CVE source"""
 
@@ -41,7 +55,7 @@ class OSVSource(NvdSource):
         # For performance do not retain the whole data in-memory
         # See: https://github.com/AppThreat/vulnerability-db/issues/27
         data_list = []
-        for _, url in config.osv_url_dict.items():
+        for _, url in config.OSV_URL_DICT.items():
             data = self.fetch(url)
             if data:
                 self.store(data)
@@ -107,6 +121,9 @@ class OSVSource(NvdSource):
         references = orjson.dumps(references, option=orjson.OPT_NAIVE_UTC)
         if isinstance(references, bytes):
             references = references.decode("utf-8", "ignore")
+        # Offer an option to ignore malware data to keep the db size small
+        if getenv("OSV_EXCLUDE_MALWARE") and cve_id.startswith("MAL"):
+            return ret_data
         # Quality of PYSEC data is quite low missing both severity and score
         # Where a PYSEC feed also reference a github id, let's ignore it since G comes before P
         #   so it would have gotten processed
@@ -123,6 +140,7 @@ class OSVSource(NvdSource):
                     break
         assigner = "google"
         vector_string = ""
+        cvss4_vector_string = ""
         if cve_id.startswith("GHSA"):
             assigner = "github_m"
         elif cve_id.startswith("CVE"):
@@ -136,9 +154,14 @@ class OSVSource(NvdSource):
             for sv in severity_list:
                 if sv["type"] == "CVSS_V3":
                     vector_string = sv["score"]
+                elif sv["type"] == "CVSS_V4":
+                    cvss4_vector_string = sv["score"]
         # Issue 58
         cve_database_specific = cve_data.get("database_specific")
         cve_ecosystem_specific = cve_data.get("ecosystem_specific")
+        # Support for collecting affected functions
+        affected_functions = set()
+        affected_modules = set()
         if cve_database_specific:
             if cve_database_specific.get("severity"):
                 severity = cve_database_specific.get("severity")
@@ -153,6 +176,15 @@ class OSVSource(NvdSource):
                 ecosystem_specific = pkg_data.get("ecosystem_specific")
                 if ecosystem_specific.get("severity"):
                     severity = ecosystem_specific.get("severity")
+                if ecosystem_specific.get("affected_functions"):
+                    affected_functions = affected_functions.union(ecosystem_specific.get("affected_functions"))
+                if ecosystem_specific.get("affects", {}).get("functions"):
+                    affected_functions = affected_functions.union(ecosystem_specific.get("affects").get("functions"))
+                for aimp in ecosystem_specific.get("imports", []):
+                    if aimp.get("path"):
+                        affected_modules.add(aimp.get("path"))
+                    if aimp.get("symbols"):
+                        affected_functions = affected_functions.union(aimp.get("symbols"))
             if pkg_data.get("database_specific"):
                 database_specific = pkg_data.get("database_specific")
                 if database_specific.get("cwes"):
@@ -170,14 +202,24 @@ class OSVSource(NvdSource):
                             score = cvss.get("score")
                             severity = convert_score_severity(score)
             user_interaction = "REQUIRED"
+            # We give importance to cvss4 which always seems to be lower compared to cvss3
+            if cvss4_vector_string:
+                cvss4_obj = get_cvss4_from_vector(cvss4_vector_string)
+                score = cvss4_obj.get("baseScore")
+                severity = cvss4_obj.get("baseSeverity")
+                exploitability_score = score
+                attack_complexity = cvss4_obj.get("attackComplexity")
+                user_interaction = cvss4_obj.get("userInteraction")
             if vector_string:
                 cvss3_obj = get_cvss3_from_vector(vector_string)
-                score = cvss3_obj.get("baseScore")
-                severity = cvss3_obj.get("baseSeverity")
-                exploitability_score = cvss3_obj.get("temporalScore")
-                attack_complexity = cvss3_obj.get("attackComplexity")
-                user_interaction = cvss3_obj.get("userInteraction")
-            else:
+                # Fallback to CVSS 3.1 only if CVSS 4 is absent
+                if not cvss4_vector_string:
+                    score = cvss3_obj.get("baseScore")
+                    severity = cvss3_obj.get("baseSeverity")
+                    exploitability_score = cvss3_obj.get("temporalScore")
+                    attack_complexity = cvss3_obj.get("attackComplexity")
+                    user_interaction = cvss3_obj.get("userInteraction")
+            if not vector_string and not cvss4_vector_string:
                 (
                     score,
                     severity,
@@ -282,8 +324,14 @@ class OSVSource(NvdSource):
                         possible_fix_version = ev.get("fixed")
             if needs_version_backup and len(versions_list):
                 try:
-                    min_ver = min(versions_list, key=Version.parse)
-                    max_ver = max(versions_list, key=Version.parse)
+                    min_ver = min(
+                        versions_list,
+                        key=lambda x: Version.parse(x, optional_minor_and_patch=True),
+                    )
+                    max_ver = max(
+                        versions_list,
+                        key=lambda x: Version.parse(x, optional_minor_and_patch=True),
+                    )
                 except Exception:
                     min_ver = versions_list[0]
                     max_ver = versions_list[-1]
@@ -317,7 +365,21 @@ class OSVSource(NvdSource):
                     )
                     try:
                         vuln = NvdSource.convert_vuln(orjson.loads(tdata))
+                        if vuln is None:
+                            continue
                         vuln.description = compress_str(description)
+                        if affected_functions:
+                            vuln.affects = {
+                                "affected_functions": sorted(list(affected_functions)),
+                                "affected_modules": sorted(
+                                    list(
+                                        affected_modules
+                                        | functions_to_modules(affected_functions)
+                                    )
+                                ),
+                            }
+                        if cvss4_vector_string:
+                            vuln.cvss4_vector_string = cvss4_vector_string
                         ret_data.append(vuln)
                     except Exception:
                         pass
@@ -417,7 +479,25 @@ class OSVSource(NvdSource):
                             )
                             try:
                                 vuln = NvdSource.convert_vuln(orjson.loads(tdata))
+                                if vuln is None:
+                                    continue
                                 vuln.description = compress_str(description)
+                                if affected_functions:
+                                    vuln.affects = {
+                                        "affected_functions": sorted(
+                                            affected_functions
+                                        ),
+                                        "affected_modules": sorted(
+                                            list(
+                                                affected_modules
+                                                | functions_to_modules(
+                                                    affected_functions
+                                                )
+                                            )
+                                        ),
+                                    }
+                                if cvss4_vector_string:
+                                    vuln.cvss4_vector_string = cvss4_vector_string
                                 ret_data.append(vuln)
                             except Exception:
                                 pass
