@@ -5,9 +5,11 @@ import string
 from datetime import date, datetime
 from enum import Enum
 from hashlib import blake2b
+from typing import Dict, List
 from urllib.parse import parse_qs, urlparse
 
-from cvss import CVSS3
+import orjson
+from cvss import CVSS3, CVSS4
 from packageurl import PackageURL
 from semver import VersionInfo
 
@@ -59,8 +61,11 @@ class ClassNotFoundError(Exception):
 
 
 def load(d):
-    """Parses a python object from a JSON string. Every Object which should be loaded needs a constuctor that doesn't need any Arguments.
-    Arguments: Dict object; the module which contains the class, the parsed object is instance of.
+    """
+    Parses a python object from a JSON string.
+    Every Object which should be loaded needs a constuctor that doesn't need any Arguments.
+    Arguments: Dict object; the module which contains the class,
+        the parsed object is instance of.
     """
 
     def _load(d1):
@@ -244,7 +249,7 @@ def normalise_num(version_num, normal_len):
     1000
     """
     version_num = str(version_num)
-    version_num = re.sub(r"[^\d]+", "", version_num)
+    version_num = re.sub(r"\D+", "", version_num)
     if len(version_num) < normal_len:
         for _ in range(len(version_num), normal_len):
             version_num = version_num + "0"
@@ -447,10 +452,10 @@ def trim_epoch(
     )
 
 
-def vers_compare(compare_ver: str | int | float, vers: str) -> bool:
+def vers_compare(compare_ver: str | int | float | None, vers: str) -> bool:
     """Purl vers based version comparison"""
     min_version, max_version, min_excluding, max_excluding = None, None, None, None
-    if vers == "*" or compare_ver is None:
+    if vers == "*" or compare_ver is None or compare_ver == "*":
         return True
     if vers.startswith("vers:"):
         vers_parts = vers.split("/")[-1].split("|")
@@ -475,6 +480,10 @@ def vers_compare(compare_ver: str | int | float, vers: str) -> bool:
                 max_version = apart.removeprefix("<=")
             elif apart.startswith("<"):
                 max_excluding = apart.removeprefix("<")
+        # There is exactly only one version
+        if len(vers_parts) == 1 and not min_version and not max_version and not min_excluding and not max_excluding:
+            min_version = vers_parts[0].strip().replace(" ", "")
+            max_version = min_version
     return version_compare(
         compare_ver, min_version, max_version, min_excluding, max_excluding
     )
@@ -482,8 +491,8 @@ def vers_compare(compare_ver: str | int | float, vers: str) -> bool:
 
 def version_compare(
     compare_ver: str | int | float,
-    min_version: str | int | float,
-    max_version: str | int | float,
+    min_version: str | int | float | None,
+    max_version: str | int | float | None,
     mie: str | int | float | None = None,
     mae: str | int | float | None = None,
 ) -> bool:
@@ -610,9 +619,11 @@ def version_compare(
                 return False
             if mae:
                 if VersionInfo.is_valid(compare_ver) and VersionInfo.is_valid(mae):
-                    cmp_value = VersionInfo.parse(compare_ver).compare(mae)
+                    cmp_value = VersionInfo.parse(
+                        compare_ver, optional_minor_and_patch=True
+                    ).compare(mae)
                     return cmp_value < 0
-                elif "." not in compare_ver and "." not in mae:
+                if "." not in compare_ver and "." not in mae:
                     compare_ver = re.split(r"[+~]", compare_ver)[0]
                     mae = re.split(r"[+~]", mae)[0]
                     exnum = list(filter(str.isdigit, compare_ver))
@@ -651,8 +662,12 @@ def version_compare(
     # Perform semver match once we have all the required versions
     if compare_ver and min_version and max_version:
         if semver_compatible(compare_ver, min_version, max_version):
-            min_value = VersionInfo.parse(compare_ver).compare(min_version)
-            max_value = VersionInfo.parse(compare_ver).compare(max_version)
+            min_value = VersionInfo.parse(
+                compare_ver, optional_minor_and_patch=True
+            ).compare(min_version)
+            max_value = VersionInfo.parse(
+                compare_ver, optional_minor_and_patch=True
+            ).compare(max_version)
             min_check = min_value > 0 if is_min_exclude else min_value >= 0
             max_check = max_value < 0 if is_max_exclude else max_value <= 0
             return min_check and max_check
@@ -884,7 +899,7 @@ def get_default_cve_data(severity):
     return score, severity, vector_string, attack_complexity
 
 
-def get_cvss3_from_vector(vector: str) -> dict:
+def get_cvss3_from_vector(vector: str) -> Dict:
     """
     Return CVE metadata for the given vector
     :param vector: Vector
@@ -894,6 +909,16 @@ def get_cvss3_from_vector(vector: str) -> dict:
     return c.as_json()
 
 
+def get_cvss4_from_vector(vector: str) -> Dict:
+    """
+    Return CVE metadata for the given vector
+    :param vector: Vector
+    :return: CVSS4 parsed and converted to json
+    """
+    c = CVSS4(vector)
+    return c.as_json()
+
+
 def convert_to_occurrence(datas):
     """Method to parse raw search result and convert to Vulnerability occurence
 
@@ -969,7 +994,7 @@ def fix_text(text):
     return text
 
 
-def convert_md_references(md_text):
+def convert_md_references(md_text: str) -> List:
     """Method to convert markdown list to references url format"""
     if not md_text:
         return []
@@ -986,7 +1011,7 @@ def convert_md_references(md_text):
     return ref_list
 
 
-def parse_purl(purl_str: str) -> dict:
+def parse_purl(purl_str: str) -> Dict:
     """Method to parse a package url string safely"""
     purl_obj = None
     if purl_str and purl_str.startswith("pkg:"):
@@ -1058,7 +1083,7 @@ def decompress_str(s):
     return s
 
 
-def to_purl_vers(vendor: str, versions: list) -> str:
+def to_purl_vers(vendor: str, versions: List) -> str:
     vers_list = []
     scheme = VENDOR_TO_VERS_SCHEME.get(vendor, vendor)
     if vendor.startswith("git") or not vendor.isalpha():
@@ -1094,30 +1119,36 @@ def to_purl_vers(vendor: str, versions: list) -> str:
                     vers_list.append("*")
                     continue
                 elif version == less_than_or_equal:
+                    if "(" in version:
+                        version = version.replace("(", "-").replace(")", "").replace("\\", "")
                     vers_list.append(version)
                     continue
                 else:
                     vers_list.append(f">={version}")
             if less_than and less_than != "*" and not less_than_or_equal:
-                vers_list.append(f"<{less_than}")
+                # Fix for #142
+                if version == "0.0.0" and check_hex(less_than):
+                    vers_list = [f"<{less_than}"]
+                else:
+                    vers_list.append(f"<{less_than}")
             if not less_than and less_than_or_equal:
                 if less_than_or_equal == "*":
                     vers_list.append("*")
                 else:
                     vers_list.append(f"<={less_than_or_equal}")
 
-    return f"vers:{scheme}/{'|'.join(vers_list)}" if vers_list else None
+    return f"vers:{scheme}/{'|'.join(vers_list)}" if vers_list else ""
 
 
-def calculate_hash(content: str, digest_size=16) -> str:
+def calculate_hash(content: str, digest_size: int = 16) -> str:
     """Function to calculate has using blake2b algorithm"""
     h = blake2b(digest_size=digest_size)
     h.update(content.encode())
     return h.hexdigest()
 
 
-def url_to_purl(url: str) -> dict | None:
-    """Convert a given http url to purl objecg"""
+def url_to_purl(url: str) -> Dict:
+    """Convert a given http url to purl object"""
     url_obj = urlparse(url)
     git_repo_name = url_obj.hostname
     version = None
@@ -1146,28 +1177,68 @@ def url_to_purl(url: str) -> dict | None:
         for v in ("commit", "tag", "hash", "version", "id"):
             if query_obj.get(v):
                 version = query_obj.get(v)[0].split(";")[0]
-    git_repo_name = (
-        git_repo_name.removesuffix("-").removesuffix("/commit").removesuffix(".git")
-    )
+    git_repo_name = git_repo_name.removesuffix("-").removesuffix("/commit").removesuffix(".git")
     url_obj = urlparse(f"https://{git_repo_name}")
     # Fix for #112
     pkg_type = "generic"
-    hostname = url_obj.hostname
-    if url_obj.hostname in ("github.com", "gitlab.com"):
-        pkg_type = url_obj.hostname.removesuffix(".com")
-        git_repo_name = url_obj.path
+    # Fix for #143
+    hostname = url_obj.hostname.removeprefix("www.")
+    if hostname in ("github.com", "gitlab.com", "nixos.org"):
+        pkg_type = hostname.removesuffix(".com").removesuffix(".org")
         hostname = None
     # Filter repo names without a path
     # eg: github.com
     if not url_obj.path:
-        return None
+        return {}
     purl_obj = parse_purl(
         f"pkg:{pkg_type}/{url_obj.hostname}/{url_obj.path}"
         if hostname
         else f"pkg:{pkg_type}/{url_obj.path}"
     )
     if not purl_obj or not purl_obj["namespace"] or not purl_obj["name"]:
-        return None
+        return {}
     if not purl_obj["version"] and version:
         purl_obj["version"] = version
     return purl_obj
+
+
+def clean_cpe_uri(cpe_uri: str) -> str:
+    if not cpe_uri:
+        return cpe_uri
+    cpe_uri = re.sub(r"[\\!&,()+\[\]]" , "", cpe_uri)
+    cpe_uri = cpe_uri.replace("_-_" , "-")
+    cpe_uri = cpe_uri.replace("_/_" , "/")
+    cpe_uri = cpe_uri.replace("__" , "_")
+    cpe_uri = cpe_uri.replace("@" , "_")
+    return cpe_uri
+
+
+def extract_affected_symbols(description: str) -> Dict:
+    """
+    Method to extract affected_modules and affected_functions from the description
+    """
+    mod_file_extns = r".*\.(c|cc|cpp|h|java|rb|py|S|o|php)$"
+    affected_functions = set()
+    affected_modules = set()
+    if description:
+        words = description.strip().split(" ")
+        for word in words:
+            if not word or word.startswith("http") or "\n" in word or "```" in word or "#" in word or re.match(
+                    r"^(v|V|v.|V.)?[0-9]", word) or word.startswith("(") or word.startswith(
+                    "CVSS") or ".." in word or word.startswith("/") or "?" in word or word.startswith("AV:"):
+                continue
+            word = word.removesuffix(",").removesuffix(".").replace("`", "").strip()
+            if re.match(mod_file_extns, word) or word.count(".") > 2 or word.count("/") > 2:
+                affected_modules.add(re.sub(r"\.(c|cc|cpp|h|java|rb|py|S|o)$", "", word))
+            elif not re.match(r"^([._$])", word) and ("_" in word or word.endswith("()")):
+                affected_functions.add(word.replace("()", ""))
+    return {
+        "affected_functions": sorted(affected_functions),
+        "affected_modules": sorted(affected_modules),
+    }
+
+
+def load_json(filepath: str) -> Dict:
+    with open(filepath, encoding="utf-8", mode="r") as fp:
+        cdx_obj = orjson.loads(fp.read())
+    return cdx_obj
